@@ -36,6 +36,7 @@
 #include "shared/readline/readline.h"
 #include "shared/runtime/pyexec.h"
 #include "shared/runtime/softtimer.h"
+#include "shared/tinyusb/mp_usbd.h"
 #include "lib/oofatfs/ff.h"
 #include "lib/littlefs/lfs1.h"
 #include "lib/littlefs/lfs1_util.h"
@@ -63,7 +64,6 @@
 #include "usrsw.h"
 #include "rtc.h"
 #include "storage.h"
-#include "tusb.h"
 #if MICROPY_PY_LWIP
 #include "lwip/init.h"
 #include "lwip/apps/mdns.h"
@@ -77,15 +77,15 @@
 #define RA_EARLY_PRINT  1       /* for enabling mp_print in boardctrl. */
 
 #if MICROPY_PY_THREAD
-STATIC pyb_thread_t pyb_thread_main;
+static pyb_thread_t pyb_thread_main;
 #endif
 
 #if defined(MICROPY_HW_UART_REPL)
 #ifndef MICROPY_HW_UART_REPL_RXBUF
 #define MICROPY_HW_UART_REPL_RXBUF (260)
 #endif
-STATIC machine_uart_obj_t machine_uart_repl_obj;
-STATIC uint8_t machine_uart_repl_rxbuf[MICROPY_HW_UART_REPL_RXBUF];
+static machine_uart_obj_t machine_uart_repl_obj;
+static uint8_t machine_uart_repl_rxbuf[MICROPY_HW_UART_REPL_RXBUF];
 #endif
 
 void NORETURN __fatal_error(const char *msg) {
@@ -126,7 +126,7 @@ void MP_WEAK __assert_func(const char *file, int line, const char *func, const c
 }
 #endif
 
-STATIC mp_obj_t pyb_main(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
+static mp_obj_t pyb_main(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
     static const mp_arg_t allowed_args[] = {
         { MP_QSTR_opt, MP_ARG_INT, {.u_int = 0} }
     };
@@ -147,7 +147,7 @@ MP_DEFINE_CONST_FUN_OBJ_KW(pyb_main_obj, 1, pyb_main);
 
 #if MICROPY_HW_FLASH_MOUNT_AT_BOOT
 // avoid inlining to avoid stack usage within main()
-MP_NOINLINE STATIC bool init_flash_fs(uint reset_mode) {
+MP_NOINLINE static bool init_flash_fs(uint reset_mode) {
     if (reset_mode == BOARDCTRL_RESET_MODE_FACTORY_FILESYSTEM) {
         // Asked by user to reset filesystem
         factory_reset_create_filesystem();
@@ -270,10 +270,6 @@ int main(void) {
     state.reset_mode = 1;
     state.log_soft_reset = false;
 
-    #if MICROPY_HW_ENABLE_USBDEV
-    tusb_init();
-    #endif
-
     #if MICROPY_PY_BLUETOOTH
     mp_bluetooth_hci_init();
     #endif
@@ -366,14 +362,20 @@ soft_reset:
     #endif
 
     // Run boot.py (or whatever else a board configures at this stage).
-    if (MICROPY_BOARD_RUN_BOOT_PY(&state) == BOARDCTRL_GOTO_SOFT_RESET_EXIT) {
-        goto soft_reset_exit;
-    }
+    int boot_res = MICROPY_BOARD_RUN_BOOT_PY(&state);
 
     // Now we initialise sub-systems that need configuration from boot.py,
     // or whose initialisation can be safely deferred until after running
     // boot.py.
 
+    #if MICROPY_HW_ENABLE_USBDEV
+    mp_usbd_init();
+    #endif
+
+    if (boot_res == BOARDCTRL_GOTO_SOFT_RESET_EXIT) {
+        goto soft_reset_exit;
+    }
+
     // At this point everything is fully configured and initialised.
 
     // Run main.py (or whatever else a board configures at this stage).
