@@ -69,8 +69,13 @@
 #define MAX_BUFFER_SIZE  (32766)
 
 #define IS_VALID_PERIPH(uart, pin)  (((((pin) + 4) & 8) >> 3) == (uart))
+#if PICO_RP2350
+#define IS_VALID_TX(uart, pin)      (((pin) & 1) == 0 && IS_VALID_PERIPH(uart, pin))
+#define IS_VALID_RX(uart, pin)      (((pin) & 1) == 1 && IS_VALID_PERIPH(uart, pin))
+#else
 #define IS_VALID_TX(uart, pin)      (((pin) & 3) == 0 && IS_VALID_PERIPH(uart, pin))
 #define IS_VALID_RX(uart, pin)      (((pin) & 3) == 1 && IS_VALID_PERIPH(uart, pin))
+#endif
 #define IS_VALID_CTS(uart, pin)     (((pin) & 3) == 2 && IS_VALID_PERIPH(uart, pin))
 #define IS_VALID_RTS(uart, pin)     (((pin) & 3) == 3 && IS_VALID_PERIPH(uart, pin))
 
@@ -80,11 +85,15 @@
 
 #define UART_HWCONTROL_CTS  (1)
 #define UART_HWCONTROL_RTS  (2)
+// OR-ed IRQ flags which are allowed to be used by the user
+#define MP_UART_ALLOWED_FLAGS (UART_UARTMIS_RTMIS_BITS | UART_UARTMIS_TXMIS_BITS | UART_UARTMIS_BEMIS_BITS)
+#define UART_FIFO_SIZE_RX           (32)
+#define UART_FIFO_TRIGGER_LEVEL_RX  (24)
 
-STATIC mutex_t write_mutex_0;
-STATIC mutex_t write_mutex_1;
-STATIC mutex_t read_mutex_0;
-STATIC mutex_t read_mutex_1;
+static mutex_t write_mutex_0;
+static mutex_t write_mutex_1;
+static mutex_t read_mutex_0;
+static mutex_t read_mutex_1;
 
 auto_init_mutex(write_mutex_0);
 auto_init_mutex(write_mutex_1);
@@ -111,19 +120,22 @@ typedef struct _machine_uart_obj_t {
     mutex_t *read_mutex;
     ringbuf_t write_buffer;
     mutex_t *write_mutex;
+    uint16_t mp_irq_trigger;   // user IRQ trigger mask
+    uint16_t mp_irq_flags;     // user IRQ active IRQ flags
+    mp_irq_obj_t *mp_irq_obj;  // user IRQ object
 } machine_uart_obj_t;
 
-STATIC machine_uart_obj_t machine_uart_obj[] = {
+static machine_uart_obj_t machine_uart_obj[] = {
     {{&machine_uart_type}, uart0, 0, 0, DEFAULT_UART_BITS, UART_PARITY_NONE, DEFAULT_UART_STOP,
      MICROPY_HW_UART0_TX, MICROPY_HW_UART0_RX, MICROPY_HW_UART0_CTS, MICROPY_HW_UART0_RTS,
-     0, 0, 0, 0, {NULL, 1, 0, 0}, &read_mutex_0, {NULL, 1, 0, 0}, &write_mutex_0},
+     0, 0, 0, 0, {NULL, 1, 0, 0}, &read_mutex_0, {NULL, 1, 0, 0}, &write_mutex_0, 0, 0, NULL},
     {{&machine_uart_type}, uart1, 1, 0, DEFAULT_UART_BITS, UART_PARITY_NONE, DEFAULT_UART_STOP,
      MICROPY_HW_UART1_TX, MICROPY_HW_UART1_RX, MICROPY_HW_UART1_CTS, MICROPY_HW_UART1_RTS,
      0, 0, 0, 0, {NULL, 1, 0, 0}, &read_mutex_1, {NULL, 1, 0, 0}, &write_mutex_1},
 };
 
-STATIC const char *_parity_name[] = {"None", "0", "1"};
-STATIC const char *_invert_name[] = {"None", "INV_TX", "INV_RX", "INV_TX|INV_RX"};
+static const char *_parity_name[] = {"None", "0", "1"};
+static const char *_invert_name[] = {"None", "INV_TX", "INV_RX", "INV_TX|INV_RX"};
 
 /******************************************************************************/
 // IRQ and buffer handling
@@ -144,14 +156,15 @@ static inline void read_mutex_unlock(machine_uart_obj_t *u) {
     mutex_exit(u->read_mutex);
 }
 
-// take all bytes from the fifo and store them in the buffer
-STATIC void uart_drain_rx_fifo(machine_uart_obj_t *self) {
+// take at most max_items bytes from the fifo and store them in the buffer
+static void uart_drain_rx_fifo(machine_uart_obj_t *self, uint32_t max_items) {
     if (read_mutex_try_lock(self)) {
-        while (uart_is_readable(self->uart) && ringbuf_free(&self->read_buffer) > 0) {
+        while (uart_is_readable(self->uart) && ringbuf_free(&self->read_buffer) > 0 && max_items > 0) {
             // Get a byte from uart and put into the buffer. Every entry from
             // the FIFO is accompanied by 4 error bits, that may be used for
             // error handling.
             uint16_t c = uart_get_hw(self->uart)->dr;
+            max_items -= 1;
             if (c & UART_UARTDR_OE_BITS) {
                 // Overrun Error: We missed at least one byte. Not much we can do here.
             }
@@ -176,7 +189,7 @@ STATIC void uart_drain_rx_fifo(machine_uart_obj_t *self) {
 
 // take bytes from the buffer and put them into the UART FIFO
 // Re-entrancy: quit if an instance already running
-STATIC void uart_fill_tx_fifo(machine_uart_obj_t *self) {
+static void uart_fill_tx_fifo(machine_uart_obj_t *self) {
     if (write_mutex_try_lock(self)) {
         while (uart_is_writable(self->uart) && ringbuf_avail(&self->write_buffer) > 0) {
             // get a byte from the buffer and put it into the uart
@@ -186,24 +199,39 @@ STATIC void uart_fill_tx_fifo(machine_uart_obj_t *self) {
     }
 }
 
-STATIC inline void uart_service_interrupt(machine_uart_obj_t *self) {
-    if (uart_get_hw(self->uart)->mis & (UART_UARTMIS_RXMIS_BITS | UART_UARTMIS_RTMIS_BITS)) { // rx interrupt?
-        // clear all interrupt bits but tx
-        uart_get_hw(self->uart)->icr = UART_UARTICR_BITS & (~UART_UARTICR_TXIC_BITS);
-        uart_drain_rx_fifo(self);
+static inline void uart_service_interrupt(machine_uart_obj_t *self) {
+    uint16_t mp_irq_flags = uart_get_hw(self->uart)->mis & (UART_UARTMIS_RXMIS_BITS | UART_UARTMIS_RTMIS_BITS);
+    if (mp_irq_flags) { // rx interrupt?
+        // clear all interrupt bits but tx and break
+        uart_get_hw(self->uart)->icr = UART_UARTICR_BITS & ~(UART_UARTICR_TXIC_BITS | UART_UARTICR_BEIC_BITS);
+        uart_drain_rx_fifo(self, UART_FIFO_TRIGGER_LEVEL_RX - 1);
     }
     if (uart_get_hw(self->uart)->mis & UART_UARTMIS_TXMIS_BITS) { // tx interrupt?
-        // clear all interrupt bits but rx
-        uart_get_hw(self->uart)->icr = UART_UARTICR_BITS & (~UART_UARTICR_RXIC_BITS);
-        uart_fill_tx_fifo(self);
+        // clear all interrupt bits but rx and break
+        uart_get_hw(self->uart)->icr = UART_UARTICR_BITS & ~(UART_UARTICR_RXIC_BITS | UART_UARTICR_RTIC_BITS | UART_UARTICR_BEIC_BITS);
+        if (ringbuf_avail(&self->write_buffer) == 0) {
+            mp_irq_flags |= UART_UARTMIS_TXMIS_BITS;
+        } else {
+            uart_fill_tx_fifo(self);
+        }
+    }
+    if (uart_get_hw(self->uart)->mis & UART_UARTMIS_BEMIS_BITS) { // break interrupt?
+        // CLear the event
+        hw_set_bits(&uart_get_hw(self->uart)->icr, UART_UARTICR_BEIC_BITS);
+        mp_irq_flags |= UART_UARTMIS_BEMIS_BITS;
+    }
+    // Check the flags to see if the user handler should be called
+    if (self->mp_irq_trigger & mp_irq_flags) {
+        self->mp_irq_flags = mp_irq_flags;
+        mp_irq_handler(self->mp_irq_obj);
     }
 }
 
-STATIC void uart0_irq_handler(void) {
+static void uart0_irq_handler(void) {
     uart_service_interrupt(&machine_uart_obj[0]);
 }
 
-STATIC void uart1_irq_handler(void) {
+static void uart1_irq_handler(void) {
     uart_service_interrupt(&machine_uart_obj[1]);
 }
 
@@ -215,17 +243,20 @@ STATIC void uart1_irq_handler(void) {
     { MP_ROM_QSTR(MP_QSTR_INV_RX), MP_ROM_INT(UART_INVERT_RX) }, \
     { MP_ROM_QSTR(MP_QSTR_CTS), MP_ROM_INT(UART_HWCONTROL_CTS) }, \
     { MP_ROM_QSTR(MP_QSTR_RTS), MP_ROM_INT(UART_HWCONTROL_RTS) }, \
+    { MP_ROM_QSTR(MP_QSTR_IRQ_RXIDLE), MP_ROM_INT(UART_UARTMIS_RTMIS_BITS) }, \
+    { MP_ROM_QSTR(MP_QSTR_IRQ_TXIDLE), MP_ROM_INT(UART_UARTMIS_TXMIS_BITS) }, \
+    { MP_ROM_QSTR(MP_QSTR_IRQ_BREAK), MP_ROM_INT(UART_UARTMIS_BEMIS_BITS) }, \
 
-STATIC void mp_machine_uart_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
+static void mp_machine_uart_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
     machine_uart_obj_t *self = MP_OBJ_TO_PTR(self_in);
     mp_printf(print, "UART(%u, baudrate=%u, bits=%u, parity=%s, stop=%u, tx=%d, rx=%d, "
-        "txbuf=%d, rxbuf=%d, timeout=%u, timeout_char=%u, invert=%s)",
+        "txbuf=%d, rxbuf=%d, timeout=%u, timeout_char=%u, invert=%s, irq=%d)",
         self->uart_id, self->baudrate, self->bits, _parity_name[self->parity],
         self->stop, self->tx, self->rx, self->write_buffer.size - 1, self->read_buffer.size - 1,
-        self->timeout, self->timeout_char, _invert_name[self->invert]);
+        self->timeout, self->timeout_char, _invert_name[self->invert], self->mp_irq_trigger);
 }
 
-STATIC void mp_machine_uart_init_helper(machine_uart_obj_t *self, size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
+static void mp_machine_uart_init_helper(machine_uart_obj_t *self, size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
     enum { ARG_baudrate, ARG_bits, ARG_parity, ARG_stop, ARG_tx, ARG_rx, ARG_cts, ARG_rts,
            ARG_timeout, ARG_timeout_char, ARG_invert, ARG_flow, ARG_txbuf, ARG_rxbuf};
     static const mp_arg_t allowed_args[] = {
@@ -359,6 +390,7 @@ STATIC void mp_machine_uart_init_helper(machine_uart_obj_t *self, size_t n_args,
     if (n_args > 0 || kw_args->used > 0 || self->baudrate == 0) {
         if (self->baudrate == 0) {
             self->baudrate = DEFAULT_UART_BAUDRATE;
+            self->timeout_char = 0;
         }
 
         // Make sure timeout_char is at least as long as a whole character (13 bits to be safe).
@@ -369,11 +401,11 @@ STATIC void mp_machine_uart_init_helper(machine_uart_obj_t *self, size_t n_args,
 
         uart_init(self->uart, self->baudrate);
         uart_set_format(self->uart, self->bits, self->stop, self->parity);
-        __DSB(); // make sure UARTLCR_H register is written to
+        __dsb(); // make sure UARTLCR_H register is written to
         uart_set_fifo_enabled(self->uart, true);
-        __DSB(); // make sure UARTLCR_H register is written to
-        gpio_set_function(self->tx, GPIO_FUNC_UART);
-        gpio_set_function(self->rx, GPIO_FUNC_UART);
+        __dsb(); // make sure UARTLCR_H register is written to
+        gpio_set_function(self->tx, UART_FUNCSEL_NUM(self->uart, self->tx));
+        gpio_set_function(self->rx, UART_FUNCSEL_NUM(self->uart, self->rx));
         if (self->invert & UART_INVERT_RX) {
             gpio_set_inover(self->rx, GPIO_OVERRIDE_INVERT);
         }
@@ -411,7 +443,7 @@ STATIC void mp_machine_uart_init_helper(machine_uart_obj_t *self, size_t n_args,
     }
 }
 
-STATIC mp_obj_t mp_machine_uart_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_kw, const mp_obj_t *args) {
+static mp_obj_t mp_machine_uart_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_kw, const mp_obj_t *args) {
     mp_arg_check_num(n_args, n_kw, 1, MP_OBJ_FUN_ARGS_MAX, true);
 
     // Get UART bus.
@@ -431,7 +463,8 @@ STATIC mp_obj_t mp_machine_uart_make_new(const mp_obj_type_t *type, size_t n_arg
     return MP_OBJ_FROM_PTR(self);
 }
 
-STATIC void mp_machine_uart_deinit(machine_uart_obj_t *self) {
+static void mp_machine_uart_deinit(machine_uart_obj_t *self) {
+    uart_tx_wait_blocking(self->uart); // Flush TX FIFO if necessary
     uart_deinit(self->uart);
     if (self->uart_id == 0) {
         irq_set_enabled(UART0_IRQ, false);
@@ -441,26 +474,106 @@ STATIC void mp_machine_uart_deinit(machine_uart_obj_t *self) {
     self->baudrate = 0;
     MP_STATE_PORT(rp2_uart_rx_buffer[self->uart_id]) = NULL;
     MP_STATE_PORT(rp2_uart_tx_buffer[self->uart_id]) = NULL;
+    MP_STATE_PORT(rp2_uart_irq_obj)[self->uart_id] = NULL;
+    self->mp_irq_obj = NULL;
+    self->mp_irq_trigger = 0;
 }
 
-STATIC mp_int_t mp_machine_uart_any(machine_uart_obj_t *self) {
+void machine_uart_deinit_all() {
+    mp_machine_uart_deinit((machine_uart_obj_t *)&machine_uart_obj[0]);
+    mp_machine_uart_deinit((machine_uart_obj_t *)&machine_uart_obj[1]);
+}
+
+static mp_int_t mp_machine_uart_any(machine_uart_obj_t *self) {
     // get all bytes from the fifo first
-    uart_drain_rx_fifo(self);
+    uart_drain_rx_fifo(self, UART_FIFO_SIZE_RX + 1);
     return ringbuf_avail(&self->read_buffer);
 }
 
-STATIC bool mp_machine_uart_txdone(machine_uart_obj_t *self) {
+static bool mp_machine_uart_txdone(machine_uart_obj_t *self) {
+    // TX is done when: nothing in the ringbuf, TX FIFO is empty, TX output is not busy.
     return ringbuf_avail(&self->write_buffer) == 0
-           && (uart_get_hw(self->uart)->fr & UART_UARTFR_TXFE_BITS);
+           && (uart_get_hw(self->uart)->fr & (UART_UARTFR_TXFE_BITS | UART_UARTFR_BUSY_BITS)) == UART_UARTFR_TXFE_BITS;
 }
 
-STATIC void mp_machine_uart_sendbreak(machine_uart_obj_t *self) {
+static void mp_machine_uart_sendbreak(machine_uart_obj_t *self) {
     uart_set_break(self->uart, true);
     mp_hal_delay_us(13000000 / self->baudrate + 1);
     uart_set_break(self->uart, false);
 }
 
-STATIC mp_uint_t mp_machine_uart_read(mp_obj_t self_in, void *buf_in, mp_uint_t size, int *errcode) {
+static void uart_set_irq_level(machine_uart_obj_t *self, uint16_t trigger) {
+    if (trigger & UART_UARTMIS_BEMIS_BITS) {
+        // Enable the break Interrupt
+        hw_set_bits(&uart_get_hw(self->uart)->imsc, UART_UARTIMSC_BEIM_BITS);
+    } else {
+        // Disable the break Interrupt
+        hw_clear_bits(&uart_get_hw(self->uart)->imsc, UART_UARTIMSC_BEIM_BITS);
+    }
+    if (trigger & UART_UARTMIS_RTMIS_BITS) {
+        // Set the RX trigger level to 3/4 FIFO_size
+        hw_write_masked(&uart_get_hw(self->uart)->ifls, 0b011 << UART_UARTIFLS_RXIFLSEL_LSB,
+                UART_UARTIFLS_RXIFLSEL_BITS);
+    } else {
+        // Set the RX trigger level to 1/8 FIFO_size
+        hw_write_masked(&uart_get_hw(self->uart)->ifls, 0 << UART_UARTIFLS_RXIFLSEL_LSB,
+                UART_UARTIFLS_RXIFLSEL_BITS);
+    }
+}
+
+static mp_uint_t uart_irq_trigger(mp_obj_t self_in, mp_uint_t new_trigger) {
+    machine_uart_obj_t *self = MP_OBJ_TO_PTR(self_in);
+    self->mp_irq_trigger = new_trigger;
+    uart_set_irq_level(self, new_trigger);
+    return 0;
+}
+
+static mp_uint_t uart_irq_info(mp_obj_t self_in, mp_uint_t info_type) {
+    machine_uart_obj_t *self = MP_OBJ_TO_PTR(self_in);
+    if (info_type == MP_IRQ_INFO_FLAGS) {
+        return self->mp_irq_flags;
+    } else if (info_type == MP_IRQ_INFO_TRIGGERS) {
+        return self->mp_irq_trigger;
+    }
+    return 0;
+}
+
+static const mp_irq_methods_t uart_irq_methods = {
+    .trigger = uart_irq_trigger,
+    .info = uart_irq_info,
+};
+
+static mp_irq_obj_t *mp_machine_uart_irq(machine_uart_obj_t *self, bool any_args, mp_arg_val_t *args) {
+    if (self->mp_irq_obj == NULL) {
+        self->mp_irq_trigger = 0;
+        self->mp_irq_obj = mp_irq_new(&uart_irq_methods, MP_OBJ_FROM_PTR(self));
+        MP_STATE_PORT(rp2_uart_irq_obj)[self->uart_id] = self->mp_irq_obj;
+    }
+
+    if (any_args) {
+        // Check the handler
+        mp_obj_t handler = args[MP_IRQ_ARG_INIT_handler].u_obj;
+        if (handler != mp_const_none && !mp_obj_is_callable(handler)) {
+            mp_raise_ValueError(MP_ERROR_TEXT("handler must be None or callable"));
+        }
+
+        // Check the trigger
+        mp_uint_t trigger = args[MP_IRQ_ARG_INIT_trigger].u_int;
+        mp_uint_t not_supported = trigger & ~MP_UART_ALLOWED_FLAGS;
+        if (trigger != 0 && not_supported) {
+            mp_raise_msg_varg(&mp_type_ValueError, MP_ERROR_TEXT("trigger 0x%04x unsupported"), not_supported);
+        }
+
+        self->mp_irq_obj->handler = handler;
+        self->mp_irq_obj->ishard = args[MP_IRQ_ARG_INIT_hard].u_bool;
+        self->mp_irq_trigger = trigger;
+        uart_set_irq_level(self, trigger);
+    }
+
+    return self->mp_irq_obj;
+}
+
+static mp_uint_t mp_machine_uart_read(mp_obj_t self_in, void *buf_in, mp_uint_t size, int *errcode) {
     machine_uart_obj_t *self = MP_OBJ_TO_PTR(self_in);
     mp_uint_t start = mp_hal_ticks_ms();
     mp_uint_t timeout = self->timeout;
@@ -471,7 +584,7 @@ STATIC mp_uint_t mp_machine_uart_read(mp_obj_t self_in, void *buf_in, mp_uint_t
         while (ringbuf_avail(&self->read_buffer) == 0) {
             if (uart_is_readable(self->uart)) {
                 // Force a few incoming bytes to the buffer
-                uart_drain_rx_fifo(self);
+                uart_drain_rx_fifo(self, UART_FIFO_SIZE_RX + 1);
                 break;
             }
             mp_uint_t elapsed = mp_hal_ticks_ms() - start;
@@ -483,7 +596,7 @@ STATIC mp_uint_t mp_machine_uart_read(mp_obj_t self_in, void *buf_in, mp_uint_t
                     return i;
                 }
             }
-            mp_event_wait_ms(timeout - elapsed);
+            mp_event_handle_nowait();
         }
         *dest++ = ringbuf_get(&(self->read_buffer));
         start = mp_hal_ticks_ms(); // Inter-character timeout
@@ -492,7 +605,7 @@ STATIC mp_uint_t mp_machine_uart_read(mp_obj_t self_in, void *buf_in, mp_uint_t
     return size;
 }
 
-STATIC mp_uint_t mp_machine_uart_write(mp_obj_t self_in, const void *buf_in, mp_uint_t size, int *errcode) {
+static mp_uint_t mp_machine_uart_write(mp_obj_t self_in, const void *buf_in, mp_uint_t size, int *errcode) {
     machine_uart_obj_t *self = MP_OBJ_TO_PTR(self_in);
     mp_uint_t start = mp_hal_ticks_ms();
     mp_uint_t timeout = self->timeout;
@@ -534,7 +647,7 @@ STATIC mp_uint_t mp_machine_uart_write(mp_obj_t self_in, const void *buf_in, mp_
     return size;
 }
 
-STATIC mp_uint_t mp_machine_uart_ioctl(mp_obj_t self_in, mp_uint_t request, uintptr_t arg, int *errcode) {
+static mp_uint_t mp_machine_uart_ioctl(mp_obj_t self_in, mp_uint_t request, uintptr_t arg, int *errcode) {
     machine_uart_obj_t *self = self_in;
     mp_uint_t ret;
     if (request == MP_STREAM_POLL) {
@@ -559,7 +672,7 @@ STATIC mp_uint_t mp_machine_uart_ioctl(mp_obj_t self_in, mp_uint_t request, uint
             if (now >= timeout) {
                 break;
             }
-            mp_event_wait_ms((timeout - now) / 1000);
+            mp_event_handle_nowait();
         }
         *errcode = MP_ETIMEDOUT;
         ret = MP_STREAM_ERROR;
@@ -572,3 +685,4 @@ STATIC mp_uint_t mp_machine_uart_ioctl(mp_obj_t self_in, mp_uint_t request, uint
 
 MP_REGISTER_ROOT_POINTER(void *rp2_uart_rx_buffer[2]);
 MP_REGISTER_ROOT_POINTER(void *rp2_uart_tx_buffer[2]);
+MP_REGISTER_ROOT_POINTER(void *rp2_uart_irq_obj[2]);
