@@ -32,21 +32,23 @@
 #include "shared/runtime/softtimer.h"
 #include "shared/timeutils/timeutils.h"
 #include "shared/tinyusb/mp_usbd.h"
+#include "shared/tinyusb/mp_usbd_cdc.h"
 #include "pendsv.h"
 #include "tusb.h"
 #include "uart.h"
-#include "hardware/rtc.h"
+#include "hardware/irq.h"
 #include "pico/unique_id.h"
+#include "pico/aon_timer.h"
 
 #if MICROPY_PY_NETWORK_CYW43
 #include "lib/cyw43-driver/src/cyw43.h"
 #endif
 
+#if PICO_RP2040
 // This needs to be added to the result of time_us_64() to get the number of
 // microseconds since the Epoch.
-STATIC uint64_t time_us_64_offset_from_epoch;
-
-static alarm_id_t soft_timer_alarm_id = 0;
+static uint64_t time_us_64_offset_from_epoch;
+#endif
 
 #if MICROPY_HW_ENABLE_UART_REPL || MICROPY_HW_USB_CDC
 
@@ -54,73 +56,19 @@ static alarm_id_t soft_timer_alarm_id = 0;
 #define MICROPY_HW_STDIN_BUFFER_LEN 512
 #endif
 
-STATIC uint8_t stdin_ringbuf_array[MICROPY_HW_STDIN_BUFFER_LEN];
+static uint8_t stdin_ringbuf_array[MICROPY_HW_STDIN_BUFFER_LEN];
 ringbuf_t stdin_ringbuf = { stdin_ringbuf_array, sizeof(stdin_ringbuf_array) };
 
 #endif
 
-#if MICROPY_HW_USB_CDC
-
-uint8_t cdc_itf_pending; // keep track of cdc interfaces which need attention to poll
-
-void poll_cdc_interfaces(void) {
-    if (!cdc_itf_pending) {
-        // Explicitly run the USB stack as the scheduler may be locked (eg we are in
-        // an interrupt handler) while there is data pending.
-        mp_usbd_task();
-    }
-
-    // any CDC interfaces left to poll?
-    if (cdc_itf_pending && ringbuf_free(&stdin_ringbuf)) {
-        for (uint8_t itf = 0; itf < 8; ++itf) {
-            if (cdc_itf_pending & (1 << itf)) {
-                tud_cdc_rx_cb(itf);
-                if (!cdc_itf_pending) {
-                    break;
-                }
-            }
-        }
-    }
-}
-
-void tud_cdc_rx_cb(uint8_t itf) {
-    // consume pending USB data immediately to free usb buffer and keep the endpoint from stalling.
-    // in case the ringbuffer is full, mark the CDC interface that need attention later on for polling
-    cdc_itf_pending &= ~(1 << itf);
-    for (uint32_t bytes_avail = tud_cdc_n_available(itf); bytes_avail > 0; --bytes_avail) {
-        if (ringbuf_free(&stdin_ringbuf)) {
-            int data_char = tud_cdc_read_char();
-            if (data_char == mp_interrupt_char) {
-                mp_sched_keyboard_interrupt();
-            } else {
-                ringbuf_put(&stdin_ringbuf, data_char);
-            }
-        } else {
-            cdc_itf_pending |= (1 << itf);
-            return;
-        }
-    }
-}
-
-#endif
-
 uintptr_t mp_hal_stdio_poll(uintptr_t poll_flags) {
     uintptr_t ret = 0;
     #if MICROPY_HW_USB_CDC
-    poll_cdc_interfaces();
+    ret |= mp_usbd_cdc_poll_interfaces(poll_flags);
     #endif
-    #if MICROPY_HW_ENABLE_UART_REPL || MICROPY_HW_USB_CDC
-    if ((poll_flags & MP_STREAM_POLL_RD) && ringbuf_peek(&stdin_ringbuf) != -1) {
-        ret |= MP_STREAM_POLL_RD;
-    }
+    #if MICROPY_HW_ENABLE_UART_REPL
     if (poll_flags & MP_STREAM_POLL_WR) {
-        #if MICROPY_HW_ENABLE_UART_REPL
         ret |= MP_STREAM_POLL_WR;
-        #else
-        if (tud_cdc_connected() && tud_cdc_write_available() > 0) {
-            ret |= MP_STREAM_POLL_WR;
-        }
-        #endif
     }
     #endif
     #if MICROPY_PY_OS_DUPTERM
@@ -133,7 +81,7 @@ uintptr_t mp_hal_stdio_poll(uintptr_t poll_flags) {
 int mp_hal_stdin_rx_chr(void) {
     for (;;) {
         #if MICROPY_HW_USB_CDC
-        poll_cdc_interfaces();
+        mp_usbd_cdc_poll_interfaces(0);
         #endif
 
         int c = ringbuf_get(&stdin_ringbuf);
@@ -160,32 +108,10 @@ mp_uint_t mp_hal_stdout_tx_strn(const char *str, mp_uint_t len) {
     #endif
 
     #if MICROPY_HW_USB_CDC
-    if (tud_cdc_connected()) {
-        size_t i = 0;
-        while (i < len) {
-            uint32_t n = len - i;
-            if (n > CFG_TUD_CDC_EP_BUFSIZE) {
-                n = CFG_TUD_CDC_EP_BUFSIZE;
-            }
-            int timeout = 0;
-            // Wait with a max of USC_CDC_TIMEOUT ms
-            while (n > tud_cdc_write_available() && timeout++ < MICROPY_HW_USB_CDC_TX_TIMEOUT) {
-                mp_event_wait_ms(1);
-
-                // Explicitly run the USB stack as the scheduler may be locked (eg we
-                // are in an interrupt handler), while there is data pending.
-                mp_usbd_task();
-            }
-            if (timeout >= MICROPY_HW_USB_CDC_TX_TIMEOUT) {
-                ret = i;
-                break;
-            }
-            uint32_t n2 = tud_cdc_write(str + i, n);
-            tud_cdc_write_flush();
-            i += n2;
-        }
-        ret = MIN(i, ret);
+    mp_uint_t cdc_res = mp_usbd_cdc_tx_strn(str, len);
+    if (cdc_res > 0) {
         did_write = true;
+        ret = MIN(cdc_res, ret);
     }
     #endif
 
@@ -199,35 +125,68 @@ mp_uint_t mp_hal_stdout_tx_strn(const char *str, mp_uint_t len) {
     return did_write ? ret : 0;
 }
 
+#if PICO_RISCV
+__attribute__((naked)) mp_uint_t mp_hal_ticks_cpu(void) {
+    __asm volatile (
+        "li a0, 4\n" // mask value to uninhibit mcycle counter
+        "csrw mcountinhibit, a0\n" // uninhibit mcycle counter
+        "csrr a0, mcycle\n" // get mcycle counter
+        "ret\n"
+        );
+}
+#endif
+
+void mp_hal_delay_us(mp_uint_t us) {
+    // Avoid calling sleep_us() and invoking the alarm pool by splitting long
+    // sleeps into an optional longer sleep and a shorter busy-wait
+    uint64_t end = time_us_64() + us;
+    if (us > 1000) {
+        mp_hal_delay_ms(us / 1000);
+    }
+    while (time_us_64() < end) {
+        // Tight loop busy-wait for accurate timing
+    }
+}
+
 void mp_hal_delay_ms(mp_uint_t ms) {
-    absolute_time_t t = make_timeout_time_ms(ms);
+    mp_uint_t start = mp_hal_ticks_ms();
+    mp_uint_t elapsed = 0;
     do {
-        mp_event_handle_nowait();
-    } while (!best_effort_wfe_or_timeout(t));
+        mp_event_wait_ms(ms - elapsed);
+        elapsed = mp_hal_ticks_ms() - start;
+    } while (elapsed < ms);
 }
 
 void mp_hal_time_ns_set_from_rtc(void) {
-    // Delay at least one RTC clock cycle so it's registers have updated with the most
-    // recent time settings.
-    sleep_us(23);
+    #if PICO_RP2040
+    // Outstanding RTC register writes need at least two RTC clock cycles to
+    // update. (See RP2040 datasheet section 4.8.4 "Reference clock").
+    mp_hal_delay_us(44);
 
     // Sample RTC and time_us_64() as close together as possible, so the offset
     // calculated for the latter can be as accurate as possible.
-    datetime_t t;
-    rtc_get_datetime(&t);
+    struct timespec ts;
+    aon_timer_get_time(&ts);
     uint64_t us = time_us_64();
 
-    // Calculate the difference between the RTC Epoch seconds and time_us_64().
-    uint64_t s = timeutils_seconds_since_epoch(t.year, t.month, t.day, t.hour, t.min, t.sec);
-    time_us_64_offset_from_epoch = (uint64_t)s * 1000000ULL - us;
+    // Calculate the difference between the RTC Epoch and time_us_64().
+    time_us_64_offset_from_epoch = ((uint64_t)ts.tv_sec * 1000000ULL) + ((uint64_t)ts.tv_nsec / 1000ULL) - us;
+    #endif
 }
 
 uint64_t mp_hal_time_ns(void) {
-    // The RTC only has seconds resolution, so instead use time_us_64() to get a more
+    #if PICO_RP2040
+    // The RTC probably has limited resolution, so instead use time_us_64() to get a more
     // precise measure of Epoch time.  Both these "clocks" are clocked from the same
     // source so they remain synchronised, and only differ by a fixed offset (calculated
     // in mp_hal_time_ns_set_from_rtc).
     return (time_us_64_offset_from_epoch + time_us_64()) * 1000ULL;
+    #else
+    // aon timer has ms resolution
+    struct timespec ts;
+    aon_timer_get_time(&ts);
+    return ((uint64_t)ts.tv_sec * 1000000000ULL) + (uint64_t)ts.tv_nsec;
+    #endif
 }
 
 // Generate a random locally administered MAC address (LAA)
@@ -273,21 +232,49 @@ uint32_t storage_read_blocks(uint8_t *dest, uint32_t block_num, uint32_t num_blo
     panic_unsupported();
 }
 
-static int64_t soft_timer_callback(alarm_id_t id, void *user_data) {
-    soft_timer_alarm_id = 0;
-    pendsv_schedule_dispatch(PENDSV_DISPATCH_SOFT_TIMER, soft_timer_handler);
-    return 0; // don't reschedule this alarm
-}
-
 uint32_t soft_timer_get_ms(void) {
     return mp_hal_ticks_ms();
 }
 
 void soft_timer_schedule_at_ms(uint32_t ticks_ms) {
-    if (soft_timer_alarm_id != 0) {
-        cancel_alarm(soft_timer_alarm_id);
-    }
     int32_t ms = soft_timer_ticks_diff(ticks_ms, mp_hal_ticks_ms());
     ms = MAX(0, ms);
-    soft_timer_alarm_id = add_alarm_in_ms(ms, soft_timer_callback, NULL, true);
+    if (hardware_alarm_set_target(MICROPY_HW_SOFT_TIMER_ALARM_NUM, delayed_by_ms(get_absolute_time(), ms))) {
+        // "missed" hardware alarm target
+        hardware_alarm_force_irq(MICROPY_HW_SOFT_TIMER_ALARM_NUM);
+    }
+}
+
+static void soft_timer_hardware_callback(unsigned int alarm_num) {
+    // The timer alarm ISR needs to call here and trigger PendSV dispatch via
+    // a second ISR, as PendSV may be currently suspended by the other CPU.
+    pendsv_schedule_dispatch(PENDSV_DISPATCH_SOFT_TIMER, soft_timer_handler);
+
+    // This ISR only runs on core0, but if core1 is running Python code then it
+    // may be blocked in WFE so wake it up as well. Unfortunately this also sets
+    // the event flag on core0, so a subsequent WFE on this core will not suspend
+    #if MICROPY_PY_THREAD
+    if (core1_entry != NULL) {
+        __sev();
+    }
+    #endif
+}
+
+void soft_timer_init(void) {
+    hardware_alarm_claim(MICROPY_HW_SOFT_TIMER_ALARM_NUM);
+    hardware_alarm_set_callback(MICROPY_HW_SOFT_TIMER_ALARM_NUM, soft_timer_hardware_callback);
+}
+
+void mp_wfe_or_timeout(uint32_t timeout_ms) {
+    soft_timer_entry_t timer;
+
+    // Note the timer doesn't have an associated callback, it just exists to create a
+    // hardware interrupt to wake the CPU
+    soft_timer_static_init(&timer, SOFT_TIMER_MODE_ONE_SHOT, 0, NULL);
+    soft_timer_insert(&timer, timeout_ms);
+
+    __wfe();
+
+    // Clean up the timer node if it's not already
+    soft_timer_remove(&timer);
 }
