@@ -56,37 +56,42 @@ typedef struct _rp2_dma_ctrl_field_t {
     uint8_t read_only : 1;
 } rp2_dma_ctrl_field_t;
 
-STATIC rp2_dma_ctrl_field_t rp2_dma_ctrl_fields_table[] = {
-    { MP_QSTR_enable,        0, 1, 0 },
-    { MP_QSTR_high_pri,      1, 1, 0 },
-    { MP_QSTR_size,          2, 2, 0 },
-    { MP_QSTR_inc_read,      4, 1, 0 },
-    { MP_QSTR_inc_write,     5, 1, 0 },
-    { MP_QSTR_ring_size,     6, 4, 0 },
-    { MP_QSTR_ring_sel,     10, 1, 0 },
-    { MP_QSTR_chain_to,     11, 4, 0 },
-    { MP_QSTR_treq_sel,     15, 6, 0 },
-    { MP_QSTR_irq_quiet,    21, 1, 0 },
-    { MP_QSTR_bswap,        22, 1, 0 },
-    { MP_QSTR_sniff_en,     23, 1, 0 },
-    { MP_QSTR_busy,         24, 1, 1 },
-    // bits 25 through 28 are reserved
-    { MP_QSTR_write_err,    29, 1, 0 },
-    { MP_QSTR_read_err,     30, 1, 0 },
-    { MP_QSTR_ahb_err,      31, 1, 1 },
+static rp2_dma_ctrl_field_t rp2_dma_ctrl_fields_table[] = {
+    { MP_QSTR_enable, DMA_CH0_CTRL_TRIG_EN_LSB, 1, 0 },
+    { MP_QSTR_high_pri, DMA_CH0_CTRL_TRIG_HIGH_PRIORITY_LSB, 1, 0 },
+    { MP_QSTR_size, DMA_CH0_CTRL_TRIG_DATA_SIZE_LSB, 2, 0 },
+    { MP_QSTR_inc_read,     DMA_CH0_CTRL_TRIG_INCR_READ_LSB, 1, 0 },
+    #if PICO_RP2350
+    { MP_QSTR_inc_read_rev,  DMA_CH0_CTRL_TRIG_INCR_READ_REV_LSB, 1, 0 },
+    #endif
+    { MP_QSTR_inc_write,    DMA_CH0_CTRL_TRIG_INCR_WRITE_LSB, 1, 0 },
+    #if PICO_RP2350
+    { MP_QSTR_inc_write_rev, DMA_CH0_CTRL_TRIG_INCR_WRITE_REV_LSB, 1, 0 },
+    #endif
+    { MP_QSTR_ring_size,    DMA_CH0_CTRL_TRIG_RING_SIZE_LSB, 4, 0 },
+    { MP_QSTR_ring_sel,     DMA_CH0_CTRL_TRIG_RING_SEL_LSB, 1, 0 },
+    { MP_QSTR_chain_to,     DMA_CH0_CTRL_TRIG_CHAIN_TO_LSB, 4, 0 },
+    { MP_QSTR_treq_sel,     DMA_CH0_CTRL_TRIG_TREQ_SEL_LSB, 6, 0 },
+    { MP_QSTR_irq_quiet,    DMA_CH0_CTRL_TRIG_IRQ_QUIET_LSB, 1, 0 },
+    { MP_QSTR_bswap,        DMA_CH0_CTRL_TRIG_BSWAP_LSB, 1, 0 },
+    { MP_QSTR_sniff_en,     DMA_CH0_CTRL_TRIG_SNIFF_EN_LSB, 1, 0 },
+    { MP_QSTR_busy,         DMA_CH0_CTRL_TRIG_BUSY_LSB, 1, 1 },
+    { MP_QSTR_write_err,    DMA_CH0_CTRL_TRIG_WRITE_ERROR_LSB, 1, 0 },
+    { MP_QSTR_read_err,     DMA_CH0_CTRL_TRIG_READ_ERROR_LSB, 1, 0 },
+    { MP_QSTR_ahb_err,      DMA_CH0_CTRL_TRIG_AHB_ERROR_LSB, 1, 1 },
 };
 
-STATIC const uint32_t rp2_dma_ctrl_field_count = MP_ARRAY_SIZE(rp2_dma_ctrl_fields_table);
+static const uint32_t rp2_dma_ctrl_field_count = MP_ARRAY_SIZE(rp2_dma_ctrl_fields_table);
 
 #define REG_TYPE_COUNT       0  // Accept just integers
 #define REG_TYPE_CONF        1  // Accept integers or ctrl values
 #define REG_TYPE_ADDR_READ   2  // Accept integers, buffers or objects that can be read from
 #define REG_TYPE_ADDR_WRITE  3  // Accept integers, buffers or objects that can be written to
 
-STATIC uint32_t rp2_dma_register_value_from_obj(mp_obj_t o, int reg_type) {
+static uint32_t rp2_dma_register_value_from_obj(mp_obj_t o, int reg_type) {
     if (reg_type == REG_TYPE_ADDR_READ || reg_type == REG_TYPE_ADDR_WRITE) {
         mp_buffer_info_t buf_info;
-        mp_uint_t flags = MP_BUFFER_READ;
+        mp_uint_t flags = (reg_type == REG_TYPE_ADDR_READ) ? MP_BUFFER_READ : MP_BUFFER_WRITE;
         if (mp_get_buffer(o, &buf_info, flags)) {
             return (uint32_t)buf_info.buf;
         }
@@ -95,27 +100,25 @@ STATIC uint32_t rp2_dma_register_value_from_obj(mp_obj_t o, int reg_type) {
     return mp_obj_get_int_truncated(o);
 }
 
-STATIC void rp2_dma_irq_handler(void) {
+static void rp2_dma_irq_handler(void) {
     // Main IRQ handler
     uint32_t irq_bits = dma_hw->ints0;
-    dma_hw->ints0 = 0xffff;
 
     for (int i = 0; i < NUM_DMA_CHANNELS; i++) {
         if (irq_bits & (1u << i)) {
             mp_irq_obj_t *handler = MP_STATE_PORT(rp2_dma_irq_obj[i]);
             if (handler) {
+                // An rp2.DMA IRQ handler is registered for this channel, so handle it.
+                dma_channel_acknowledge_irq0(i);
                 rp2_dma_obj_t *self = (rp2_dma_obj_t *)handler->parent;
                 self->irq_flag = 1;
                 mp_irq_handler(handler);
-            } else {
-                // We got an interrupt with no handler. Disable the channel
-                dma_channel_set_irq0_enabled(i, false);
             }
         }
     }
 }
 
-STATIC mp_uint_t rp2_dma_irq_trigger(mp_obj_t self_in, mp_uint_t new_trigger) {
+static mp_uint_t rp2_dma_irq_trigger(mp_obj_t self_in, mp_uint_t new_trigger) {
     rp2_dma_obj_t *self = MP_OBJ_TO_PTR(self_in);
     irq_set_enabled(DMA_IRQ_0, false);
     self->irq_flag = 0;
@@ -124,7 +127,7 @@ STATIC mp_uint_t rp2_dma_irq_trigger(mp_obj_t self_in, mp_uint_t new_trigger) {
     return 0;
 }
 
-STATIC mp_uint_t rp2_dma_irq_info(mp_obj_t self_in, mp_uint_t info_type) {
+static mp_uint_t rp2_dma_irq_info(mp_obj_t self_in, mp_uint_t info_type) {
     rp2_dma_obj_t *self = MP_OBJ_TO_PTR(self_in);
     if (info_type == MP_IRQ_INFO_FLAGS) {
         return self->irq_flag;
@@ -134,12 +137,12 @@ STATIC mp_uint_t rp2_dma_irq_info(mp_obj_t self_in, mp_uint_t info_type) {
     return 0;
 }
 
-STATIC const mp_irq_methods_t rp2_dma_irq_methods = {
+static const mp_irq_methods_t rp2_dma_irq_methods = {
     .trigger = rp2_dma_irq_trigger,
     .info = rp2_dma_irq_info,
 };
 
-STATIC mp_obj_t rp2_dma_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_kw, const mp_obj_t *args) {
+static mp_obj_t rp2_dma_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_kw, const mp_obj_t *args) {
     mp_arg_check_num(n_args, n_kw, 0, 0, false);
 
     int dma_channel = dma_claim_unused_channel(false);
@@ -147,21 +150,20 @@ STATIC mp_obj_t rp2_dma_make_new(const mp_obj_type_t *type, size_t n_args, size_
         mp_raise_OSError(MP_EBUSY);
     }
 
-    rp2_dma_obj_t *self = m_new_obj_with_finaliser(rp2_dma_obj_t);
-    self->base.type = &rp2_dma_type;
+    rp2_dma_obj_t *self = mp_obj_malloc_with_finaliser(rp2_dma_obj_t, &rp2_dma_type);
     self->channel = dma_channel;
 
     // Return the DMA object.
     return MP_OBJ_FROM_PTR(self);
 }
 
-STATIC void rp2_dma_error_if_closed(rp2_dma_obj_t *self) {
+static void rp2_dma_error_if_closed(rp2_dma_obj_t *self) {
     if (self->channel == CHANNEL_CLOSED) {
         mp_raise_ValueError(MP_ERROR_TEXT("channel closed"));
     }
 }
 
-STATIC void rp2_dma_attr(mp_obj_t self_in, qstr attr_in, mp_obj_t *dest) {
+static void rp2_dma_attr(mp_obj_t self_in, qstr attr_in, mp_obj_t *dest) {
     rp2_dma_obj_t *self = MP_OBJ_TO_PTR(self_in);
 
     if (dest[0] == MP_OBJ_NULL) {
@@ -218,13 +220,13 @@ STATIC void rp2_dma_attr(mp_obj_t self_in, qstr attr_in, mp_obj_t *dest) {
     }
 }
 
-STATIC void rp2_dma_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
+static void rp2_dma_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
     rp2_dma_obj_t *self = MP_OBJ_TO_PTR(self_in);
     mp_printf(print, "DMA(%u)", self->channel);
 }
 
 // DMA.config(*, read, write, count, ctrl, trigger)
-STATIC mp_obj_t rp2_dma_config(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
+static mp_obj_t rp2_dma_config(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
     rp2_dma_obj_t *self = MP_OBJ_TO_PTR(*pos_args);
 
     rp2_dma_error_if_closed(self);
@@ -280,10 +282,10 @@ STATIC mp_obj_t rp2_dma_config(size_t n_args, const mp_obj_t *pos_args, mp_map_t
 
     return mp_const_none;
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_KW(rp2_dma_config_obj, 1, rp2_dma_config);
+static MP_DEFINE_CONST_FUN_OBJ_KW(rp2_dma_config_obj, 1, rp2_dma_config);
 
 // DMA.active([value])
-STATIC mp_obj_t rp2_dma_active(size_t n_args, const mp_obj_t *args) {
+static mp_obj_t rp2_dma_active(size_t n_args, const mp_obj_t *args) {
     rp2_dma_obj_t *self = MP_OBJ_TO_PTR(args[0]);
     rp2_dma_error_if_closed(self);
 
@@ -298,13 +300,18 @@ STATIC mp_obj_t rp2_dma_active(size_t n_args, const mp_obj_t *args) {
     uint32_t busy = dma_channel_is_busy(self->channel);
     return mp_obj_new_bool((mp_int_t)busy);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(rp2_dma_active_obj, 1, 2, rp2_dma_active);
+static MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(rp2_dma_active_obj, 1, 2, rp2_dma_active);
 
 // Default is quiet, unpaced, read and write incrementing, word transfers, enabled
-#define DEFAULT_DMA_CONFIG (1 << 21) | (0x3f << 15) | (1 << 5) | (1 << 4) | (2 << 2) | (1 << 0)
+#define DEFAULT_DMA_CONFIG (1 << DMA_CH0_CTRL_TRIG_IRQ_QUIET_LSB) | \
+    (DMA_CH0_CTRL_TRIG_TREQ_SEL_VALUE_PERMANENT << DMA_CH0_CTRL_TRIG_TREQ_SEL_LSB) | \
+    (1 << DMA_CH0_CTRL_TRIG_INCR_WRITE_LSB) | \
+    (1 << DMA_CH0_CTRL_TRIG_INCR_READ_LSB) | \
+    (2 << DMA_CH0_CTRL_TRIG_DATA_SIZE_LSB) | \
+    (1 << DMA_CH0_CTRL_TRIG_EN_LSB)
 
 // DMA.pack_ctrl(...)
-STATIC mp_obj_t rp2_dma_pack_ctrl(size_t n_pos_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
+static mp_obj_t rp2_dma_pack_ctrl(size_t n_pos_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
     // Pack keyword settings into a control register value, using either the default for this
     // DMA channel or the provided defaults
     rp2_dma_obj_t *self = MP_OBJ_TO_PTR(pos_args[0]);
@@ -349,10 +356,10 @@ STATIC mp_obj_t rp2_dma_pack_ctrl(size_t n_pos_args, const mp_obj_t *pos_args, m
 
     return mp_obj_new_int_from_uint(value);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_KW(rp2_dma_pack_ctrl_obj, 1, rp2_dma_pack_ctrl);
+static MP_DEFINE_CONST_FUN_OBJ_KW(rp2_dma_pack_ctrl_obj, 1, rp2_dma_pack_ctrl);
 
 // DMA.unpack_ctrl(value)
-STATIC mp_obj_t rp2_dma_unpack_ctrl(mp_obj_t value_obj) {
+static mp_obj_t rp2_dma_unpack_ctrl(mp_obj_t value_obj) {
     // Return a dict representing the unpacked fields of a control register value
     mp_obj_t result_dict[rp2_dma_ctrl_field_count * 2];
 
@@ -367,10 +374,10 @@ STATIC mp_obj_t rp2_dma_unpack_ctrl(mp_obj_t value_obj) {
 
     return mp_obj_dict_make_new(&mp_type_dict, 0, rp2_dma_ctrl_field_count, result_dict);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(rp2_dma_unpack_ctrl_fun_obj, rp2_dma_unpack_ctrl);
-STATIC MP_DEFINE_CONST_STATICMETHOD_OBJ(rp2_dma_unpack_ctrl_obj, MP_ROM_PTR(&rp2_dma_unpack_ctrl_fun_obj));
+static MP_DEFINE_CONST_FUN_OBJ_1(rp2_dma_unpack_ctrl_fun_obj, rp2_dma_unpack_ctrl);
+static MP_DEFINE_CONST_STATICMETHOD_OBJ(rp2_dma_unpack_ctrl_obj, MP_ROM_PTR(&rp2_dma_unpack_ctrl_fun_obj));
 
-STATIC mp_obj_t rp2_dma_irq(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
+static mp_obj_t rp2_dma_irq(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
     enum { ARG_handler, ARG_hard };
     static const mp_arg_t allowed_args[] = {
         { MP_QSTR_handler, MP_ARG_OBJ, {.u_rom_obj = mp_const_none} },
@@ -389,6 +396,9 @@ STATIC mp_obj_t rp2_dma_irq(size_t n_args, const mp_obj_t *pos_args, mp_map_t *k
     if (irq == NULL) {
         irq = mp_irq_new(&rp2_dma_irq_methods, MP_OBJ_FROM_PTR(self));
         MP_STATE_PORT(rp2_dma_irq_obj[self->channel]) = irq;
+
+        // Clear any existing IRQs on this DMA channel, they are not for us.
+        dma_channel_acknowledge_irq0(self->channel);
     }
 
     if (n_args > 1 || kw_args->used != 0) {
@@ -409,10 +419,10 @@ STATIC mp_obj_t rp2_dma_irq(size_t n_args, const mp_obj_t *pos_args, mp_map_t *k
 
     return MP_OBJ_FROM_PTR(irq);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_KW(rp2_dma_irq_obj, 1, rp2_dma_irq);
+static MP_DEFINE_CONST_FUN_OBJ_KW(rp2_dma_irq_obj, 1, rp2_dma_irq);
 
 // DMA.close()
-STATIC mp_obj_t rp2_dma_close(mp_obj_t self_in) {
+static mp_obj_t rp2_dma_close(mp_obj_t self_in) {
     rp2_dma_obj_t *self = MP_OBJ_TO_PTR(self_in);
     uint8_t channel = self->channel;
 
@@ -431,9 +441,9 @@ STATIC mp_obj_t rp2_dma_close(mp_obj_t self_in) {
 
     return mp_const_none;
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(rp2_dma_close_obj, rp2_dma_close);
+static MP_DEFINE_CONST_FUN_OBJ_1(rp2_dma_close_obj, rp2_dma_close);
 
-STATIC const mp_rom_map_elem_t rp2_dma_locals_dict_table[] = {
+static const mp_rom_map_elem_t rp2_dma_locals_dict_table[] = {
     { MP_ROM_QSTR(MP_QSTR_config), MP_ROM_PTR(&rp2_dma_config_obj) },
     { MP_ROM_QSTR(MP_QSTR_active), MP_ROM_PTR(&rp2_dma_active_obj) },
     { MP_ROM_QSTR(MP_QSTR_irq), MP_ROM_PTR(&rp2_dma_irq_obj) },
@@ -442,7 +452,7 @@ STATIC const mp_rom_map_elem_t rp2_dma_locals_dict_table[] = {
     { MP_ROM_QSTR(MP_QSTR_pack_ctrl), MP_ROM_PTR(&rp2_dma_pack_ctrl_obj) },
     { MP_ROM_QSTR(MP_QSTR_unpack_ctrl), MP_ROM_PTR(&rp2_dma_unpack_ctrl_obj) },
 };
-STATIC MP_DEFINE_CONST_DICT(rp2_dma_locals_dict, rp2_dma_locals_dict_table);
+static MP_DEFINE_CONST_DICT(rp2_dma_locals_dict, rp2_dma_locals_dict_table);
 
 MP_DEFINE_CONST_OBJ_TYPE(
     rp2_dma_type,
@@ -457,12 +467,11 @@ MP_DEFINE_CONST_OBJ_TYPE(
 void rp2_dma_init(void) {
     // Set up interrupts.
     memset(MP_STATE_PORT(rp2_dma_irq_obj), 0, sizeof(MP_STATE_PORT(rp2_dma_irq_obj)));
-    irq_set_exclusive_handler(DMA_IRQ_0, rp2_dma_irq_handler);
+    irq_add_shared_handler(DMA_IRQ_0, rp2_dma_irq_handler, PICO_SHARED_IRQ_HANDLER_DEFAULT_ORDER_PRIORITY);
 }
 
 void rp2_dma_deinit(void) {
-    // Disable and clear interrupts.
-    irq_set_mask_enabled(1u << DMA_IRQ_0, false);
+    // Remove our interrupt handler.
     irq_remove_handler(DMA_IRQ_0, rp2_dma_irq_handler);
 }
 
