@@ -28,10 +28,27 @@
 
 #include "py/mpconfig.h"
 
+// Additional entries for use with pendsv_schedule_dispatch.
+#ifndef MICROPY_BOARD_PENDSV_ENTRIES
+#define MICROPY_BOARD_PENDSV_ENTRIES
+#endif
+
+#ifndef MICROPY_BOARD_FATAL_ERROR
+#define MICROPY_BOARD_FATAL_ERROR boardctrl_fatal_error
+#endif
+
 #ifndef MICROPY_BOARD_STARTUP
 #define MICROPY_BOARD_STARTUP powerctrl_check_enter_bootloader
 #endif
 
+#ifndef MICROPY_BOARD_ENTER_BOOTLOADER
+#if MICROPY_HW_USES_BOOTLOADER
+#define MICROPY_BOARD_ENTER_BOOTLOADER(nargs, args) boardctrl_maybe_enter_mboot(nargs, args)
+#else
+#define MICROPY_BOARD_ENTER_BOOTLOADER(nargs, args)
+#endif
+#endif
+
 #ifndef MICROPY_BOARD_EARLY_INIT
 #define MICROPY_BOARD_EARLY_INIT()
 #endif
@@ -60,6 +77,24 @@
 #define MICROPY_BOARD_END_SOFT_RESET boardctrl_end_soft_reset
 #endif
 
+// Called when USBD CDC data is available.
+// Default function defined in usbd_cdc_interface.h.
+#ifndef MICROPY_BOARD_USBD_CDC_RX_EVENT
+#define MICROPY_BOARD_USBD_CDC_RX_EVENT usbd_cdc_rx_event_callback
+#endif
+
+// Called to poll Bluetooth HCI now.
+// Default function defined in mpbthciport.h.
+#ifndef MICROPY_BOARD_BT_HCI_POLL_NOW
+#define MICROPY_BOARD_BT_HCI_POLL_NOW mp_bluetooth_hci_poll_now_default
+#endif
+
+// Called to poll Bluetooth HCI after the given timeout.
+// Default function defined in mpbthciport.h.
+#ifndef MICROPY_BOARD_BT_HCI_POLL_IN_MS
+#define MICROPY_BOARD_BT_HCI_POLL_IN_MS mp_bluetooth_hci_poll_in_ms_default
+#endif
+
 // Constants to return from boardctrl_run_boot_py, boardctrl_run_main_py.
 enum {
     BOARDCTRL_CONTINUE,
@@ -79,6 +114,8 @@ typedef struct _boardctrl_state_t {
     bool log_soft_reset;
 } boardctrl_state_t;
 
+NORETURN void boardctrl_fatal_error(const char *msg);
+void boardctrl_maybe_enter_mboot(size_t n_args, const void *args);
 void boardctrl_before_soft_reset_loop(boardctrl_state_t *state);
 void boardctrl_top_soft_reset_loop(boardctrl_state_t *state);
 int boardctrl_run_boot_py(boardctrl_state_t *state);
