@@ -34,41 +34,40 @@
 
 // UART buses
 // Bluetooth HCI
-#define MICROPY_HW_UART2_CTS                     (pin_D3)
-#define MICROPY_HW_UART2_RTS                     (pin_D4)
-#define MICROPY_HW_UART2_TX                      (pin_D5)
-#define MICROPY_HW_UART2_RX                      (pin_D6)
+#define MICROPY_HW_UART2_CTS                     (pyb_pin_BT_CTS)
+#define MICROPY_HW_UART2_RTS                     (pyb_pin_BT_RTS)
+#define MICROPY_HW_UART2_TX                      (pyb_pin_BT_TX)
+#define MICROPY_HW_UART2_RX                      (pyb_pin_BT_RX)
 // Port B
-#define MICROPY_HW_UART4_TX                      (pin_D1)
-#define MICROPY_HW_UART4_RX                      (pin_D0)
+#define MICROPY_HW_UART4_TX                      (pyb_pin_PORTB_TX)
+#define MICROPY_HW_UART4_RX                      (pyb_pin_PORTB_RX)
 // Port D
-#define MICROPY_HW_UART5_TX                      (pin_C12)
-#define MICROPY_HW_UART5_RX                      (pin_D2)
+#define MICROPY_HW_UART5_TX                      (pyb_pin_PORTD_TX)
+#define MICROPY_HW_UART5_RX                      (pyb_pin_PORTD_RX)
 // Port A
-#define MICROPY_HW_UART7_TX                      (pin_E8)
-#define MICROPY_HW_UART7_RX                      (pin_E7)
+#define MICROPY_HW_UART7_TX                      (pyb_pin_PORTA_TX)
+#define MICROPY_HW_UART7_RX                      (pyb_pin_PORTA_RX)
 // Port C
-#define MICROPY_HW_UART8_TX                      (pin_E1)
-#define MICROPY_HW_UART8_RX                      (pin_E0)
+#define MICROPY_HW_UART8_TX                      (pyb_pin_PORTC_TX)
+#define MICROPY_HW_UART8_RX                      (pyb_pin_PORTC_RX)
 // Port F
-#define MICROPY_HW_UART9_TX                      (pin_D15)
-#define MICROPY_HW_UART9_RX                      (pin_D14)
+#define MICROPY_HW_UART9_TX                      (pyb_pin_PORTF_TX)
+#define MICROPY_HW_UART9_RX                      (pyb_pin_PORTF_RX)
 // Port E
-#define MICROPY_HW_UART10_TX                     (pin_E3)
-#define MICROPY_HW_UART10_RX                     (pin_E2)
+#define MICROPY_HW_UART10_TX                     (pyb_pin_PORTE_TX)
+#define MICROPY_HW_UART10_RX                     (pyb_pin_PORTE_RX)
 
 // SPI buses
-#define MICROPY_HW_SPI1_NSS                      (pin_A4) // shared with DAC
-#define MICROPY_HW_SPI1_SCK                      (pin_A5) // shared with DAC
-#define MICROPY_HW_SPI1_MISO                     (pin_A6)
-#define MICROPY_HW_SPI1_MOSI                     (pin_A7)
-#define MICROPY_HW_SPI2_NSS                      (pin_B12)
-#define MICROPY_HW_SPI2_SCK                      (pin_B13)
-#define MICROPY_HW_SPI2_MISO                     (pin_C2)
-#define MICROPY_HW_SPI2_MOSI                     (pin_C3)
+#define MICROPY_HW_SPI1_SCK                      (pyb_pin_TLC_SCLK)
+#define MICROPY_HW_SPI1_MISO                     (pyb_pin_TLC_SOUT)
+#define MICROPY_HW_SPI1_MOSI                     (pyb_pin_TLC_SIN)
+#define MICROPY_HW_SPI2_NSS                      (pyb_pin_FLASH_NSS)
+#define MICROPY_HW_SPI2_SCK                      (pyb_pin_FLASH_SCK)
+#define MICROPY_HW_SPI2_MISO                     (pyb_pin_FLASH_MISO)
+#define MICROPY_HW_SPI2_MOSI                     (pyb_pin_FLASH_MOSI)
 
 // USB config
-#define MICROPY_HW_USB_VBUS_DETECT_PIN           (pin_A9)
+#define MICROPY_HW_USB_VBUS_DETECT_PIN           (pyb_pin_USB_VBUS)
 #define MICROPY_HW_USB_FS                        (1)
 #define MICROPY_HW_USB_MSC                       (1)
 
@@ -102,7 +101,7 @@
     spi_bdev_ioctl(&spi_bdev, (op), (arg)) \
     )
 
-// Configuration for stardard block protocol (block size FLASH_BLOCK_SIZE).
+// Configuration for standard block protocol (block size FLASH_BLOCK_SIZE).
 #define MICROPY_HW_BDEV_READBLOCKS(dest, bl, n) \
     spi_bdev_readblocks(&spi_bdev, (dest), MICROPY_HW_SPIFLASH_BLOCKMAP(bl), (n))
 #define MICROPY_HW_BDEV_WRITEBLOCKS(src, bl, n) \
