@@ -13,5 +13,6 @@ void *sdram_start(void);
 void *sdram_end(void);
 void sdram_enter_low_power(void);
 void sdram_leave_low_power(void);
-bool sdram_test(bool fast);
+void sdram_enter_power_down(void);
+bool sdram_test(bool exhaustive);
 #endif // __SDRAM_H__
