@@ -98,7 +98,7 @@ extern PCD_HandleTypeDef pcd_hs_handle;
 // More information about decoding the fault registers can be found here:
 // http://infocenter.arm.com/help/index.jsp?topic=/com.arm.doc.dui0646a/Cihdjcfc.html
 
-STATIC char *fmt_hex(uint32_t val, char *buf) {
+static char *fmt_hex(uint32_t val, char *buf) {
     const char *hexDig = "0123456789abcdef";
 
     buf[0] = hexDig[(val >> 28) & 0x0f];
@@ -114,7 +114,7 @@ STATIC char *fmt_hex(uint32_t val, char *buf) {
     return buf;
 }
 
-STATIC void print_reg(const char *label, uint32_t val) {
+static void print_reg(const char *label, uint32_t val) {
     char hexStr[9];
 
     mp_hal_stdout_tx_str(label);
@@ -122,7 +122,7 @@ STATIC void print_reg(const char *label, uint32_t val) {
     mp_hal_stdout_tx_str("\r\n");
 }
 
-STATIC void print_hex_hex(const char *label, uint32_t val1, uint32_t val2) {
+static void print_hex_hex(const char *label, uint32_t val1, uint32_t val2) {
     char hex_str[9];
     mp_hal_stdout_tx_str(label);
     mp_hal_stdout_tx_str(fmt_hex(val1, hex_str));
@@ -312,7 +312,7 @@ void USB_DRD_FS_IRQHandler(void) {
 }
 #endif
 
-#elif defined(STM32L0) || defined(STM32L432xx)
+#elif defined(STM32L0) || defined(STM32L432xx) || defined(STM32L452xx)
 
 #if MICROPY_HW_USB_FS
 void USB_IRQHandler(void) {
@@ -356,7 +356,7 @@ void OTG_HS_IRQHandler(void) {
   * @param  *pcd_handle for FS or HS
   * @retval None
   */
-STATIC void OTG_CMD_WKUP_Handler(PCD_HandleTypeDef *pcd_handle) {
+static void OTG_CMD_WKUP_Handler(PCD_HandleTypeDef *pcd_handle) {
 
     if (pcd_handle->Init.low_power_enable) {
         /* Reset SLEEPDEEP bit of Cortex System Control Register */
@@ -514,7 +514,7 @@ void PVD_IRQHandler(void) {
     IRQ_EXIT(PVD_IRQn);
 }
 
-#if defined(STM32L4)
+#if defined(STM32L4) || defined(STM32WB) || defined(STM32WL)
 void PVD_PVM_IRQHandler(void) {
     IRQ_ENTER(PVD_PVM_IRQn);
     Handle_EXTI_Irq(EXTI_PVD_OUTPUT);
