@@ -107,13 +107,13 @@ typedef struct _mp_obj_fficallback_t {
     ffi_type *params[];
 } mp_obj_fficallback_t;
 
-// STATIC const mp_obj_type_t opaque_type;
-STATIC const mp_obj_type_t ffimod_type;
-STATIC const mp_obj_type_t ffifunc_type;
-STATIC const mp_obj_type_t fficallback_type;
-STATIC const mp_obj_type_t ffivar_type;
+// static const mp_obj_type_t opaque_type;
+static const mp_obj_type_t ffimod_type;
+static const mp_obj_type_t ffifunc_type;
+static const mp_obj_type_t fficallback_type;
+static const mp_obj_type_t ffivar_type;
 
-STATIC ffi_type *char2ffi_type(char c) {
+static ffi_type *char2ffi_type(char c) {
     switch (c) {
         case 'b':
             return &ffi_type_schar;
@@ -154,7 +154,7 @@ STATIC ffi_type *char2ffi_type(char c) {
     }
 }
 
-STATIC ffi_type *get_ffi_type(mp_obj_t o_in) {
+static ffi_type *get_ffi_type(mp_obj_t o_in) {
     if (mp_obj_is_str(o_in)) {
         const char *s = mp_obj_str_get_str(o_in);
         ffi_type *t = char2ffi_type(*s);
@@ -167,14 +167,14 @@ STATIC ffi_type *get_ffi_type(mp_obj_t o_in) {
     mp_raise_TypeError(MP_ERROR_TEXT("unknown type"));
 }
 
-STATIC mp_obj_t return_ffi_value(ffi_union_t *val, char type) {
+static mp_obj_t return_ffi_value(ffi_union_t *val, char type) {
     switch (type) {
         case 's': {
             const char *s = (const char *)(intptr_t)val->ffi;
             if (!s) {
                 return mp_const_none;
             }
-            return mp_obj_new_str(s, strlen(s));
+            return mp_obj_new_str_from_cstr(s);
         }
         case 'v':
             return mp_const_none;
@@ -190,10 +190,13 @@ STATIC mp_obj_t return_ffi_value(ffi_union_t *val, char type) {
         case 'h':
         case 'i':
         case 'l':
-            return mp_obj_new_int((signed)val->ffi);
+            return mp_obj_new_int((ffi_sarg)val->ffi);
+        case 'I':
+            // On RV64, 32-bit values are stored as signed integers inside the
+            // holding register.
+            return mp_obj_new_int_from_uint(val->ffi & 0xFFFFFFFF);
         case 'B':
         case 'H':
-        case 'I':
         case 'L':
             return mp_obj_new_int_from_uint(val->ffi);
         case 'q':
@@ -209,25 +212,25 @@ STATIC mp_obj_t return_ffi_value(ffi_union_t *val, char type) {
 
 // FFI module
 
-STATIC void ffimod_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
+static void ffimod_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
     (void)kind;
     mp_obj_ffimod_t *self = MP_OBJ_TO_PTR(self_in);
     mp_printf(print, "<ffimod %p>", self->handle);
 }
 
-STATIC mp_obj_t ffimod_close(mp_obj_t self_in) {
+static mp_obj_t ffimod_close(mp_obj_t self_in) {
     mp_obj_ffimod_t *self = MP_OBJ_TO_PTR(self_in);
     dlclose(self->handle);
     return mp_const_none;
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(ffimod_close_obj, ffimod_close);
+static MP_DEFINE_CONST_FUN_OBJ_1(ffimod_close_obj, ffimod_close);
 
-STATIC mp_obj_t make_func(mp_obj_t rettype_in, void *func, mp_obj_t argtypes_in) {
+static mp_obj_t make_func(mp_obj_t rettype_in, void *func, mp_obj_t argtypes_in) {
     const char *rettype = mp_obj_str_get_str(rettype_in);
     const char *argtypes = mp_obj_str_get_str(argtypes_in);
 
     mp_int_t nparams = MP_OBJ_SMALL_INT_VALUE(mp_obj_len_maybe(argtypes_in));
-    mp_obj_ffifunc_t *o = mp_obj_malloc_var(mp_obj_ffifunc_t, ffi_type *, nparams, &ffifunc_type);
+    mp_obj_ffifunc_t *o = mp_obj_malloc_var(mp_obj_ffifunc_t, params, ffi_type *, nparams, &ffifunc_type);
 
     o->func = func;
     o->rettype = *rettype;
@@ -249,7 +252,7 @@ STATIC mp_obj_t make_func(mp_obj_t rettype_in, void *func, mp_obj_t argtypes_in)
     return MP_OBJ_FROM_PTR(o);
 }
 
-STATIC mp_obj_t ffimod_func(size_t n_args, const mp_obj_t *args) {
+static mp_obj_t ffimod_func(size_t n_args, const mp_obj_t *args) {
     (void)n_args; // always 4
     mp_obj_ffimod_t *self = MP_OBJ_TO_PTR(args[0]);
     const char *symname = mp_obj_str_get_str(args[2]);
@@ -262,13 +265,13 @@ STATIC mp_obj_t ffimod_func(size_t n_args, const mp_obj_t *args) {
 }
 MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(ffimod_func_obj, 4, 4, ffimod_func);
 
-STATIC mp_obj_t mod_ffi_func(mp_obj_t rettype, mp_obj_t addr_in, mp_obj_t argtypes) {
+static mp_obj_t mod_ffi_func(mp_obj_t rettype, mp_obj_t addr_in, mp_obj_t argtypes) {
     void *addr = (void *)MP_OBJ_TO_PTR(mp_obj_int_get_truncated(addr_in));
     return make_func(rettype, addr, argtypes);
 }
 MP_DEFINE_CONST_FUN_OBJ_3(mod_ffi_func_obj, mod_ffi_func);
 
-STATIC void call_py_func(ffi_cif *cif, void *ret, void **args, void *user_data) {
+static void call_py_func(ffi_cif *cif, void *ret, void **args, void *user_data) {
     mp_obj_t pyargs[cif->nargs];
     mp_obj_fficallback_t *o = user_data;
     mp_obj_t pyfunc = o->pyfunc;
@@ -283,7 +286,7 @@ STATIC void call_py_func(ffi_cif *cif, void *ret, void **args, void *user_data)
     }
 }
 
-STATIC void call_py_func_with_lock(ffi_cif *cif, void *ret, void **args, void *user_data) {
+static void call_py_func_with_lock(ffi_cif *cif, void *ret, void **args, void *user_data) {
     mp_obj_t pyargs[cif->nargs];
     mp_obj_fficallback_t *o = user_data;
     mp_obj_t pyfunc = o->pyfunc;
@@ -316,7 +319,7 @@ STATIC void call_py_func_with_lock(ffi_cif *cif, void *ret, void **args, void *u
     #endif
 }
 
-STATIC mp_obj_t mod_ffi_callback(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
+static mp_obj_t mod_ffi_callback(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
     // first 3 args are positional: retttype, func, paramtypes.
     mp_obj_t rettype_in = pos_args[0];
     mp_obj_t func_in = pos_args[1];
@@ -334,7 +337,8 @@ STATIC mp_obj_t mod_ffi_callback(size_t n_args, const mp_obj_t *pos_args, mp_map
     const char *rettype = mp_obj_str_get_str(rettype_in);
 
     mp_int_t nparams = MP_OBJ_SMALL_INT_VALUE(mp_obj_len_maybe(paramtypes_in));
-    mp_obj_fficallback_t *o = mp_obj_malloc_var(mp_obj_fficallback_t, ffi_type *, nparams, &fficallback_type);
+    mp_obj_fficallback_t *o = (mp_obj_fficallback_t *)m_tracked_calloc(offsetof(mp_obj_fficallback_t, params) + sizeof(ffi_type *) * nparams, sizeof(uint8_t));
+    o->base.type = &fficallback_type;
 
     o->clo = ffi_closure_alloc(sizeof(ffi_closure), &o->func);
 
@@ -364,7 +368,7 @@ STATIC mp_obj_t mod_ffi_callback(size_t n_args, const mp_obj_t *pos_args, mp_map
 }
 MP_DEFINE_CONST_FUN_OBJ_KW(mod_ffi_callback_obj, 3, mod_ffi_callback);
 
-STATIC mp_obj_t ffimod_var(mp_obj_t self_in, mp_obj_t vartype_in, mp_obj_t symname_in) {
+static mp_obj_t ffimod_var(mp_obj_t self_in, mp_obj_t vartype_in, mp_obj_t symname_in) {
     mp_obj_ffimod_t *self = MP_OBJ_TO_PTR(self_in);
     const char *rettype = mp_obj_str_get_str(vartype_in);
     const char *symname = mp_obj_str_get_str(symname_in);
@@ -381,7 +385,7 @@ STATIC mp_obj_t ffimod_var(mp_obj_t self_in, mp_obj_t vartype_in, mp_obj_t symna
 }
 MP_DEFINE_CONST_FUN_OBJ_3(ffimod_var_obj, ffimod_var);
 
-STATIC mp_obj_t ffimod_addr(mp_obj_t self_in, mp_obj_t symname_in) {
+static mp_obj_t ffimod_addr(mp_obj_t self_in, mp_obj_t symname_in) {
     mp_obj_ffimod_t *self = MP_OBJ_TO_PTR(self_in);
     const char *symname = mp_obj_str_get_str(symname_in);
 
@@ -393,7 +397,7 @@ STATIC mp_obj_t ffimod_addr(mp_obj_t self_in, mp_obj_t symname_in) {
 }
 MP_DEFINE_CONST_FUN_OBJ_2(ffimod_addr_obj, ffimod_addr);
 
-STATIC mp_obj_t ffimod_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_kw, const mp_obj_t *args) {
+static mp_obj_t ffimod_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_kw, const mp_obj_t *args) {
     (void)n_args;
     (void)n_kw;
 
@@ -411,16 +415,16 @@ STATIC mp_obj_t ffimod_make_new(const mp_obj_type_t *type, size_t n_args, size_t
     return MP_OBJ_FROM_PTR(o);
 }
 
-STATIC const mp_rom_map_elem_t ffimod_locals_dict_table[] = {
+static const mp_rom_map_elem_t ffimod_locals_dict_table[] = {
     { MP_ROM_QSTR(MP_QSTR_func), MP_ROM_PTR(&ffimod_func_obj) },
     { MP_ROM_QSTR(MP_QSTR_var), MP_ROM_PTR(&ffimod_var_obj) },
     { MP_ROM_QSTR(MP_QSTR_addr), MP_ROM_PTR(&ffimod_addr_obj) },
     { MP_ROM_QSTR(MP_QSTR_close), MP_ROM_PTR(&ffimod_close_obj) },
 };
 
-STATIC MP_DEFINE_CONST_DICT(ffimod_locals_dict, ffimod_locals_dict_table);
+static MP_DEFINE_CONST_DICT(ffimod_locals_dict, ffimod_locals_dict_table);
 
-STATIC MP_DEFINE_CONST_OBJ_TYPE(
+static MP_DEFINE_CONST_OBJ_TYPE(
     ffimod_type,
     MP_QSTR_ffimod,
     MP_TYPE_FLAG_NONE,
@@ -431,13 +435,13 @@ STATIC MP_DEFINE_CONST_OBJ_TYPE(
 
 // FFI function
 
-STATIC void ffifunc_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
+static void ffifunc_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
     (void)kind;
     mp_obj_ffifunc_t *self = MP_OBJ_TO_PTR(self_in);
     mp_printf(print, "<ffifunc %p>", self->func);
 }
 
-STATIC unsigned long long ffi_get_int_value(mp_obj_t o) {
+static unsigned long long ffi_get_int_value(mp_obj_t o) {
     if (mp_obj_is_small_int(o)) {
         return MP_OBJ_SMALL_INT_VALUE(o);
     } else {
@@ -447,7 +451,7 @@ STATIC unsigned long long ffi_get_int_value(mp_obj_t o) {
     }
 }
 
-STATIC ffi_union_t ffi_int_obj_to_ffi_union(mp_obj_t o, const char argtype) {
+static ffi_union_t ffi_int_obj_to_ffi_union(mp_obj_t o, const char argtype) {
     ffi_union_t ret;
     if ((argtype | 0x20) == 'q') {
         ret.Q = ffi_get_int_value(o);
@@ -479,7 +483,7 @@ STATIC ffi_union_t ffi_int_obj_to_ffi_union(mp_obj_t o, const char argtype) {
     return ret;
 }
 
-STATIC mp_obj_t ffifunc_call(mp_obj_t self_in, size_t n_args, size_t n_kw, const mp_obj_t *args) {
+static mp_obj_t ffifunc_call(mp_obj_t self_in, size_t n_args, size_t n_kw, const mp_obj_t *args) {
     (void)n_kw;
     mp_obj_ffifunc_t *self = MP_OBJ_TO_PTR(self_in);
     assert(n_kw == 0);
@@ -530,7 +534,7 @@ error:
     mp_raise_TypeError(MP_ERROR_TEXT("don't know how to pass object to native function"));
 }
 
-STATIC MP_DEFINE_CONST_OBJ_TYPE(
+static MP_DEFINE_CONST_OBJ_TYPE(
     ffifunc_type,
     MP_QSTR_ffifunc,
     MP_TYPE_FLAG_NONE,
@@ -540,24 +544,24 @@ STATIC MP_DEFINE_CONST_OBJ_TYPE(
 
 // FFI callback for Python function
 
-STATIC void fficallback_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
+static void fficallback_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
     (void)kind;
     mp_obj_fficallback_t *self = MP_OBJ_TO_PTR(self_in);
     mp_printf(print, "<fficallback %p>", self->func);
 }
 
-STATIC mp_obj_t fficallback_cfun(mp_obj_t self_in) {
+static mp_obj_t fficallback_cfun(mp_obj_t self_in) {
     mp_obj_fficallback_t *self = MP_OBJ_TO_PTR(self_in);
     return mp_obj_new_int_from_ull((uintptr_t)self->func);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(fficallback_cfun_obj, fficallback_cfun);
+static MP_DEFINE_CONST_FUN_OBJ_1(fficallback_cfun_obj, fficallback_cfun);
 
-STATIC const mp_rom_map_elem_t fficallback_locals_dict_table[] = {
+static const mp_rom_map_elem_t fficallback_locals_dict_table[] = {
     { MP_ROM_QSTR(MP_QSTR_cfun), MP_ROM_PTR(&fficallback_cfun_obj) }
 };
-STATIC MP_DEFINE_CONST_DICT(fficallback_locals_dict, fficallback_locals_dict_table);
+static MP_DEFINE_CONST_DICT(fficallback_locals_dict, fficallback_locals_dict_table);
 
-STATIC MP_DEFINE_CONST_OBJ_TYPE(
+static MP_DEFINE_CONST_OBJ_TYPE(
     fficallback_type,
     MP_QSTR_fficallback,
     MP_TYPE_FLAG_NONE,
@@ -567,34 +571,34 @@ STATIC MP_DEFINE_CONST_OBJ_TYPE(
 
 // FFI variable
 
-STATIC void ffivar_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
+static void ffivar_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
     (void)kind;
     mp_obj_ffivar_t *self = MP_OBJ_TO_PTR(self_in);
     // Variable value printed as cast to int
     mp_printf(print, "<ffivar @%p: 0x%x>", self->var, *(int *)self->var);
 }
 
-STATIC mp_obj_t ffivar_get(mp_obj_t self_in) {
+static mp_obj_t ffivar_get(mp_obj_t self_in) {
     mp_obj_ffivar_t *self = MP_OBJ_TO_PTR(self_in);
     return mp_binary_get_val_array(self->type, self->var, 0);
 }
 MP_DEFINE_CONST_FUN_OBJ_1(ffivar_get_obj, ffivar_get);
 
-STATIC mp_obj_t ffivar_set(mp_obj_t self_in, mp_obj_t val_in) {
+static mp_obj_t ffivar_set(mp_obj_t self_in, mp_obj_t val_in) {
     mp_obj_ffivar_t *self = MP_OBJ_TO_PTR(self_in);
     mp_binary_set_val_array(self->type, self->var, 0, val_in);
     return mp_const_none;
 }
 MP_DEFINE_CONST_FUN_OBJ_2(ffivar_set_obj, ffivar_set);
 
-STATIC const mp_rom_map_elem_t ffivar_locals_dict_table[] = {
+static const mp_rom_map_elem_t ffivar_locals_dict_table[] = {
     { MP_ROM_QSTR(MP_QSTR_get), MP_ROM_PTR(&ffivar_get_obj) },
     { MP_ROM_QSTR(MP_QSTR_set), MP_ROM_PTR(&ffivar_set_obj) },
 };
 
-STATIC MP_DEFINE_CONST_DICT(ffivar_locals_dict, ffivar_locals_dict_table);
+static MP_DEFINE_CONST_DICT(ffivar_locals_dict, ffivar_locals_dict_table);
 
-STATIC MP_DEFINE_CONST_OBJ_TYPE(
+static MP_DEFINE_CONST_OBJ_TYPE(
     ffivar_type,
     MP_QSTR_ffivar,
     MP_TYPE_FLAG_NONE,
@@ -605,7 +609,7 @@ STATIC MP_DEFINE_CONST_OBJ_TYPE(
 // Generic opaque storage object (unused)
 
 /*
-STATIC MP_DEFINE_CONST_OBJ_TYPE(
+static MP_DEFINE_CONST_OBJ_TYPE(
     opaque_type,
     MP_QSTR_opaqueval,
     MP_TYPE_FLAG_NONE,
@@ -613,17 +617,17 @@ STATIC MP_DEFINE_CONST_OBJ_TYPE(
     );
 */
 
-STATIC mp_obj_t mod_ffi_open(size_t n_args, const mp_obj_t *args) {
+static mp_obj_t mod_ffi_open(size_t n_args, const mp_obj_t *args) {
     return ffimod_make_new(&ffimod_type, n_args, 0, args);
 }
 MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(mod_ffi_open_obj, 1, 2, mod_ffi_open);
 
-STATIC mp_obj_t mod_ffi_as_bytearray(mp_obj_t ptr, mp_obj_t size) {
+static mp_obj_t mod_ffi_as_bytearray(mp_obj_t ptr, mp_obj_t size) {
     return mp_obj_new_bytearray_by_ref(mp_obj_int_get_truncated(size), (void *)(uintptr_t)mp_obj_int_get_truncated(ptr));
 }
 MP_DEFINE_CONST_FUN_OBJ_2(mod_ffi_as_bytearray_obj, mod_ffi_as_bytearray);
 
-STATIC const mp_rom_map_elem_t mp_module_ffi_globals_table[] = {
+static const mp_rom_map_elem_t mp_module_ffi_globals_table[] = {
     { MP_ROM_QSTR(MP_QSTR___name__), MP_ROM_QSTR(MP_QSTR_ffi) },
     { MP_ROM_QSTR(MP_QSTR_open), MP_ROM_PTR(&mod_ffi_open_obj) },
     { MP_ROM_QSTR(MP_QSTR_callback), MP_ROM_PTR(&mod_ffi_callback_obj) },
@@ -631,7 +635,7 @@ STATIC const mp_rom_map_elem_t mp_module_ffi_globals_table[] = {
     { MP_ROM_QSTR(MP_QSTR_as_bytearray), MP_ROM_PTR(&mod_ffi_as_bytearray_obj) },
 };
 
-STATIC MP_DEFINE_CONST_DICT(mp_module_ffi_globals, mp_module_ffi_globals_table);
+static MP_DEFINE_CONST_DICT(mp_module_ffi_globals, mp_module_ffi_globals_table);
 
 const mp_obj_module_t mp_module_ffi = {
     .base = { &mp_type_module },
