@@ -60,21 +60,21 @@ typedef struct _mp_thread_t {
     struct _mp_thread_t *next;
 } mp_thread_t;
 
-STATIC pthread_key_t tls_key;
+static pthread_key_t tls_key;
 
 // The mutex is used for any code in this port that needs to be thread safe.
 // Specifically for thread management, access to the linked list is one example.
 // But also, e.g. scheduler state.
-STATIC pthread_mutex_t thread_mutex;
-STATIC mp_thread_t *thread;
+static pthread_mutex_t thread_mutex;
+static mp_thread_t *thread;
 
 // this is used to synchronise the signal handler of the thread
 // it's needed because we can't use any pthread calls in a signal handler
 #if defined(__APPLE__)
-STATIC char thread_signal_done_name[25];
-STATIC sem_t *thread_signal_done_p;
+static char thread_signal_done_name[25];
+static sem_t *thread_signal_done_p;
 #else
-STATIC sem_t thread_signal_done;
+static sem_t thread_signal_done;
 #endif
 
 void mp_thread_unix_begin_atomic_section(void) {
@@ -86,7 +86,7 @@ void mp_thread_unix_end_atomic_section(void) {
 }
 
 // this signal handler is used to scan the regs and stack of a thread
-STATIC void mp_thread_gc(int signo, siginfo_t *info, void *context) {
+static void mp_thread_gc(int signo, siginfo_t *info, void *context) {
     (void)info; // unused
     (void)context; // unused
     if (signo == MP_THREAD_GC_SIGNAL) {
