@@ -1,10 +1,6 @@
 # test sys.path
 
-try:
-    import usys as sys
-except ImportError:
-    import sys
-
+import sys
 # check that this script was executed from a file of the same name
 if "__file__" not in globals() or "sys_path.py" not in __file__:
     print("SKIP")
