@@ -6,6 +6,11 @@ except ImportError:
     print("SKIP")
     raise SystemExit
 
+# CPython 3.12 deprecated calling get_event_loop() when there is no current event
+# loop, so to make this test run on CPython requires setting the event loop.
+if hasattr(asyncio, "set_event_loop"):
+    asyncio.set_event_loop(asyncio.new_event_loop())
+
 
 async def task():
     for i in range(4):
