@@ -1,10 +1,10 @@
 # Test for VfsLittle using a RAM device, file IO
 
 try:
-    import os
+    import vfs
 
-    os.VfsLfs1
-    os.VfsLfs2
+    vfs.VfsLfs1
+    vfs.VfsLfs2
 except (ImportError, AttributeError):
     print("SKIP")
     raise SystemExit
@@ -42,10 +42,10 @@ def test(bdev, vfs_class):
     vfs_class.mkfs(bdev)
 
     # construction
-    vfs = vfs_class(bdev)
+    fs = vfs_class(bdev)
 
     # create text, print, write, close
-    f = vfs.open("test.txt", "wt")
+    f = fs.open("test.txt", "wt")
     print(f)
     f.write("littlefs")
     f.close()
@@ -54,48 +54,48 @@ def test(bdev, vfs_class):
     f.close()
 
     # create binary, print, write, flush, close
-    f = vfs.open("test.bin", "wb")
+    f = fs.open("test.bin", "wb")
     print(f)
     f.write("littlefs")
     f.flush()
     f.close()
 
     # create for append
-    f = vfs.open("test.bin", "ab")
+    f = fs.open("test.bin", "ab")
     f.write("more")
     f.close()
 
     # create exclusive
-    f = vfs.open("test2.bin", "xb")
+    f = fs.open("test2.bin", "xb")
     f.close()
 
     # create exclusive with error
     try:
-        vfs.open("test2.bin", "x")
+        fs.open("test2.bin", "x")
     except OSError:
         print("open OSError")
 
     # read default
-    with vfs.open("test.txt", "") as f:
+    with fs.open("test.txt", "") as f:
         print(f.read())
 
     # read text
-    with vfs.open("test.txt", "rt") as f:
+    with fs.open("test.txt", "rt") as f:
         print(f.read())
 
     # read binary
-    with vfs.open("test.bin", "rb") as f:
+    with fs.open("test.bin", "rb") as f:
         print(f.read())
 
     # create read and write
-    with vfs.open("test.bin", "r+b") as f:
+    with fs.open("test.bin", "r+b") as f:
         print(f.read(8))
         f.write("MORE")
-    with vfs.open("test.bin", "rb") as f:
+    with fs.open("test.bin", "rb") as f:
         print(f.read())
 
     # seek and tell
-    f = vfs.open("test.txt", "r")
+    f = fs.open("test.txt", "r")
     print(f.tell())
     f.seek(3, 0)
     print(f.tell())
@@ -103,13 +103,13 @@ def test(bdev, vfs_class):
 
     # open nonexistent
     try:
-        vfs.open("noexist", "r")
+        fs.open("noexist", "r")
     except OSError:
         print("open OSError")
 
     # open multiple files at the same time
-    f1 = vfs.open("test.txt", "")
-    f2 = vfs.open("test.bin", "b")
+    f1 = fs.open("test.txt", "")
+    f2 = fs.open("test.bin", "b")
     print(f1.read())
     print(f2.read())
     f1.close()
@@ -117,5 +117,5 @@ def test(bdev, vfs_class):
 
 
 bdev = RAMBlockDevice(30)
-test(bdev, os.VfsLfs1)
-test(bdev, os.VfsLfs2)
+test(bdev, vfs.VfsLfs1)
+test(bdev, vfs.VfsLfs2)
