@@ -13,13 +13,17 @@ from glob import glob
 sys.path.append("../tools")
 import pyboard
 
+prepare_script_for_target = __import__("run-tests").prepare_script_for_target
+
 # Paths for host executables
 if os.name == "nt":
     CPYTHON3 = os.getenv("MICROPY_CPYTHON3", "python3.exe")
-    MICROPYTHON = os.getenv("MICROPY_MICROPYTHON", "../ports/windows/micropython.exe")
+    MICROPYTHON = os.getenv(
+        "MICROPY_MICROPYTHON", "../ports/windows/build-standard/micropython.exe"
+    )
 else:
     CPYTHON3 = os.getenv("MICROPY_CPYTHON3", "python3")
-    MICROPYTHON = os.getenv("MICROPY_MICROPYTHON", "../ports/unix/micropython")
+    MICROPYTHON = os.getenv("MICROPY_MICROPYTHON", "../ports/unix/build-standard/micropython")
 
 PYTHON_TRUTH = CPYTHON3
 
@@ -33,8 +37,8 @@ def compute_stats(lst):
         avg += x
         var += x * x
     avg /= len(lst)
-    var = max(0, var / len(lst) - avg ** 2)
-    return avg, var ** 0.5
+    var = max(0, var / len(lst) - avg**2)
+    return avg, var**0.5
 
 
 def run_script_on_target(target, script):
@@ -74,6 +78,8 @@ def run_feature_test(target, test):
 def run_benchmark_on_target(target, script):
     output, err = run_script_on_target(target, script)
     if err is None:
+        if output == "SKIP":
+            return -1, -1, "SKIP"
         time, norm, result = output.split(None, 2)
         try:
             return int(time), int(norm), result
@@ -83,9 +89,10 @@ def run_benchmark_on_target(target, script):
         return -1, -1, "CRASH: %r" % err
 
 
-def run_benchmarks(target, param_n, param_m, n_average, test_list):
+def run_benchmarks(args, target, param_n, param_m, n_average, test_list):
     skip_complex = run_feature_test(target, "complex") != "complex"
     skip_native = run_feature_test(target, "native_check") != "native"
+    target_had_error = False
 
     for test_file in sorted(test_list):
         print(test_file + ": ", end="")
@@ -98,12 +105,13 @@ def run_benchmarks(target, param_n, param_m, n_average, test_list):
             and test_file.find("viper_") != -1
         )
         if skip:
-            print("skip")
+            print("SKIP")
             continue
 
         # Create test script
+        test_script = b"import sys\nsys.path.remove('')\n\n"
         with open(test_file, "rb") as f:
-            test_script = f.read()
+            test_script += f.read()
         with open(BENCH_SCRIPT_DIR + "benchrun.py", "rb") as f:
             test_script += f.read()
         test_script += b"bm_run(%u, %u)\n" % (param_n, param_m)
@@ -113,13 +121,22 @@ def run_benchmarks(target, param_n, param_m, n_average, test_list):
             with open("%s.full" % test_file, "wb") as f:
                 f.write(test_script)
 
+        # Process script through mpy-cross if needed
+        if isinstance(target, pyboard.Pyboard) or args.via_mpy:
+            crash, test_script_target = prepare_script_for_target(args, script_text=test_script)
+            if crash:
+                print("CRASH:", test_script_target)
+                continue
+        else:
+            test_script_target = test_script
+
         # Run MicroPython a given number of times
         times = []
         scores = []
         error = None
         result_out = None
         for _ in range(n_average):
-            time, norm, result = run_benchmark_on_target(target, test_script)
+            time, norm, result = run_benchmark_on_target(target, test_script_target)
             if time < 0 or norm < 0:
                 error = result
                 break
@@ -133,11 +150,20 @@ def run_benchmarks(target, param_n, param_m, n_average, test_list):
 
         # Check result against truth if needed
         if error is None and result_out != "None":
-            _, _, result_exp = run_benchmark_on_target(PYTHON_TRUTH, test_script)
+            test_file_expected = test_file + ".exp"
+            if os.path.isfile(test_file_expected):
+                # Expected result is given by a file, so read that in
+                with open(test_file_expected) as f:
+                    result_exp = f.read().strip()
+            else:
+                # Run CPython to work out the expected result
+                _, _, result_exp = run_benchmark_on_target(PYTHON_TRUTH, test_script)
             if result_out != result_exp:
                 error = "FAIL truth"
 
         if error is not None:
+            if not error.startswith("SKIP"):
+                target_had_error = True
             print(error)
         else:
             t_avg, t_sd = compute_stats(times)
@@ -153,6 +179,8 @@ def run_benchmarks(target, param_n, param_m, n_average, test_list):
 
         sys.stdout.flush()
 
+    return target_had_error
+
 
 def parse_output(filename):
     with open(filename) as f:
@@ -162,7 +190,7 @@ def parse_output(filename):
         m = int(m.split("=")[1])
         data = []
         for l in f:
-            if l.find(": ") != -1 and l.find(": skip") == -1 and l.find("CRASH: ") == -1:
+            if ": " in l and ": SKIP" not in l and "CRASH: " not in l:
                 name, values = l.strip().split(": ")
                 values = tuple(float(v) for v in values.split())
                 data.append((name,) + values)
@@ -184,7 +212,7 @@ def compute_diff(file1, file2, diff_score):
     else:
         hdr = "N={} M={} vs N={} M={}".format(n1, m1, n2, m2)
     print(
-        "{:24} {:>10} -> {:>10}   {:>10}   {:>7}% (error%)".format(
+        "{:26} {:>10} -> {:>10}   {:>10}   {:>7}% (error%)".format(
             hdr, file1, file2, "diff", "diff"
         )
     )
@@ -201,11 +229,11 @@ def compute_diff(file1, file2, diff_score):
             sd1 *= av1 / 100  # convert from percent sd to absolute sd
             sd2 *= av2 / 100  # convert from percent sd to absolute sd
             av_diff = av2 - av1
-            sd_diff = (sd1 ** 2 + sd2 ** 2) ** 0.5
+            sd_diff = (sd1**2 + sd2**2) ** 0.5
             percent = 100 * av_diff / av1
             percent_sd = 100 * sd_diff / av1
             print(
-                "{:24} {:10.2f} -> {:10.2f} : {:+10.2f} = {:+7.3f}% (+/-{:.2f}%)".format(
+                "{:26} {:10.2f} -> {:10.2f} : {:+10.2f} = {:+7.3f}% (+/-{:.2f}%)".format(
                     name, av1, av2, av_diff, percent, percent_sd
                 )
             )
@@ -233,7 +261,12 @@ def main():
     cmd_parser.add_argument(
         "--emit", default="bytecode", help="MicroPython emitter to use (bytecode or native)"
     )
-    cmd_parser.add_argument("N", nargs=1, help="N parameter (approximate target CPU frequency)")
+    cmd_parser.add_argument("--heapsize", help="heapsize to use (use default if not specified)")
+    cmd_parser.add_argument("--via-mpy", action="store_true", help="compile code to .mpy first")
+    cmd_parser.add_argument("--mpy-cross-flags", default="", help="flags to pass to mpy-cross")
+    cmd_parser.add_argument(
+        "N", nargs=1, help="N parameter (approximate target CPU frequency in MHz)"
+    )
     cmd_parser.add_argument("M", nargs=1, help="M parameter (approximate target heap in kbytes)")
     cmd_parser.add_argument("files", nargs="*", help="input test files")
     args = cmd_parser.parse_args()
@@ -250,10 +283,14 @@ def main():
     n_average = int(args.average)
 
     if args.pyboard:
+        if not args.mpy_cross_flags:
+            args.mpy_cross_flags = "-march=armv7m"
         target = pyboard.Pyboard(args.device)
         target.enter_raw_repl()
     else:
         target = [MICROPYTHON, "-X", "emit=" + args.emit]
+        if args.heapsize is not None:
+            target.extend(["-X", "heapsize=" + args.heapsize])
 
     if len(args.files) == 0:
         tests_skip = ("benchrun.py",)
@@ -270,12 +307,15 @@ def main():
 
     print("N={} M={} n_average={}".format(N, M, n_average))
 
-    run_benchmarks(target, N, M, n_average, tests)
+    target_had_error = run_benchmarks(args, target, N, M, n_average, tests)
 
     if isinstance(target, pyboard.Pyboard):
         target.exit_raw_repl()
         target.close()
 
+    if target_had_error:
+        sys.exit(1)
+
 
 if __name__ == "__main__":
     main()
