@@ -88,7 +88,7 @@ class FreezeError(Exception):
 
 class Config:
     MPY_VERSION = 6
-    MPY_SUB_VERSION = 2
+    MPY_SUB_VERSION = 3
     MICROPY_LONGINT_IMPL_NONE = 0
     MICROPY_LONGINT_IMPL_LONGLONG = 1
     MICROPY_LONGINT_IMPL_MPZ = 2
@@ -113,6 +113,7 @@ MP_NATIVE_ARCH_ARMV7EMSP = 7
 MP_NATIVE_ARCH_ARMV7EMDP = 8
 MP_NATIVE_ARCH_XTENSA = 9
 MP_NATIVE_ARCH_XTENSAWIN = 10
+MP_NATIVE_ARCH_RV32IMC = 11
 
 MP_PERSISTENT_OBJ_FUN_TABLE = 0
 MP_PERSISTENT_OBJ_NONE = 1
@@ -126,6 +127,7 @@ MP_PERSISTENT_OBJ_FLOAT = 8
 MP_PERSISTENT_OBJ_COMPLEX = 9
 MP_PERSISTENT_OBJ_TUPLE = 10
 
+MP_SCOPE_FLAG_GENERATOR = 0x01
 MP_SCOPE_FLAG_VIPERRELOC = 0x10
 MP_SCOPE_FLAG_VIPERRODATA = 0x20
 MP_SCOPE_FLAG_VIPERBSS = 0x40
@@ -683,7 +685,7 @@ class CompiledModule:
         else:
             print("        .obj_table = NULL,")
         print("    },")
-        print("    .rc = &raw_code_%s," % self.raw_code.escaped_name)
+        print("    .proto_fun = &proto_fun_%s," % self.raw_code.escaped_name)
         print("};")
 
     def freeze_constant_obj(self, obj_name, obj):
@@ -733,8 +735,8 @@ class CompiledModule:
             elif config.MICROPY_LONGINT_IMPL == config.MICROPY_LONGINT_IMPL_NONE:
                 raise FreezeError(self, "target does not support long int")
             elif config.MICROPY_LONGINT_IMPL == config.MICROPY_LONGINT_IMPL_LONGLONG:
-                # TODO
-                raise FreezeError(self, "freezing int to long-long is not implemented")
+                print("static const mp_obj_int_t %s = {{&mp_type_int}, %d};" % (obj_name, obj))
+                return "MP_ROM_PTR(&%s)" % obj_name
             elif config.MICROPY_LONGINT_IMPL == config.MICROPY_LONGINT_IMPL_MPZ:
                 neg = 0
                 if obj < 0:
@@ -898,7 +900,7 @@ class RawCode(object):
                 print()
             print("static const mp_raw_code_t *const children_%s[] = {" % self.escaped_name)
             for rc in self.children:
-                print("    &raw_code_%s," % rc.escaped_name)
+                print("    (const mp_raw_code_t *)&proto_fun_%s," % rc.escaped_name)
             if prelude_ptr:
                 print("    (void *)%s," % prelude_ptr)
             print("};")
@@ -906,14 +908,23 @@ class RawCode(object):
 
     def freeze_raw_code(self, prelude_ptr=None, type_sig=0):
         # Generate mp_raw_code_t.
-        print("static const mp_raw_code_t raw_code_%s = {" % self.escaped_name)
+        if self.code_kind == MP_CODE_NATIVE_ASM:
+            raw_code_type = "mp_raw_code_t"
+        else:
+            raw_code_type = "mp_raw_code_truncated_t"
+
+        empty_children = len(self.children) == 0 and prelude_ptr is None
+        generate_minimal = self.code_kind == MP_CODE_BYTECODE and empty_children
+
+        if generate_minimal:
+            print("#if MICROPY_PERSISTENT_CODE_SAVE")
+
+        print("static const %s proto_fun_%s = {" % (raw_code_type, self.escaped_name))
+        print("    .proto_fun_indicator[0] = MP_PROTO_FUN_INDICATOR_RAW_CODE_0,")
+        print("    .proto_fun_indicator[1] = MP_PROTO_FUN_INDICATOR_RAW_CODE_1,")
         print("    .kind = %s," % RawCode.code_kind_str[self.code_kind])
-        print("    .scope_flags = 0x%02x," % self.scope_flags)
-        print("    .n_pos_args = %u," % self.n_pos_args)
+        print("    .is_generator = %d," % bool(self.scope_flags & MP_SCOPE_FLAG_GENERATOR))
         print("    .fun_data = fun_data_%s," % self.escaped_name)
-        print("    #if MICROPY_PERSISTENT_CODE_SAVE || MICROPY_DEBUG_PRINTERS")
-        print("    .fun_data_len = %u," % len(self.fun_data))
-        print("    #endif")
         if len(self.children):
             print("    .children = (void *)&children_%s," % self.escaped_name)
         elif prelude_ptr:
@@ -921,9 +932,14 @@ class RawCode(object):
         else:
             print("    .children = NULL,")
         print("    #if MICROPY_PERSISTENT_CODE_SAVE")
+        print("    .fun_data_len = %u," % len(self.fun_data))
         print("    .n_children = %u," % len(self.children))
+        print("    #if MICROPY_EMIT_MACHINE_CODE")
+        print("    .prelude_offset = %u," % self.prelude_offset)
+        print("    #endif")
         if self.code_kind == MP_CODE_BYTECODE:
             print("    #if MICROPY_PY_SYS_SETTRACE")
+            print("    .line_of_definition = %u," % 0)  # TODO
             print("    .prelude = {")
             print("        .n_state = %u," % self.prelude_signature[0])
             print("        .n_exc_stack = %u," % self.prelude_signature[1])
@@ -944,17 +960,18 @@ class RawCode(object):
                 "        .opcodes = fun_data_%s + %u," % (self.escaped_name, self.offset_opcodes)
             )
             print("    },")
-            print("    .line_of_definition = %u," % 0)  # TODO
             print("    #endif")
-        print("    #if MICROPY_EMIT_MACHINE_CODE")
-        print("    .prelude_offset = %u," % self.prelude_offset)
-        print("    #endif")
-        print("    #endif")
-        print("    #if MICROPY_EMIT_MACHINE_CODE")
-        print("    .type_sig = %u," % type_sig)
         print("    #endif")
+        if self.code_kind == MP_CODE_NATIVE_ASM:
+            print("    .asm_n_pos_args = %u," % self.n_pos_args)
+            print("    .asm_type_sig = %u," % type_sig)
         print("};")
 
+        if generate_minimal:
+            print("#else")
+            print("#define proto_fun_%s fun_data_%s[0]" % (self.escaped_name, self.escaped_name))
+            print("#endif")
+
         global raw_code_count, raw_code_content
         raw_code_count += 1
         raw_code_content += 4 * 4
@@ -1063,6 +1080,7 @@ class RawCodeNative(RawCode):
             MP_NATIVE_ARCH_X64,
             MP_NATIVE_ARCH_XTENSA,
             MP_NATIVE_ARCH_XTENSAWIN,
+            MP_NATIVE_ARCH_RV32IMC,
         ):
             self.fun_data_attributes = '__attribute__((section(".text,\\"ax\\",@progbits # ")))'
         else:
@@ -1078,8 +1096,10 @@ class RawCodeNative(RawCode):
         ):
             # ARMV6 or Xtensa -- four byte align.
             self.fun_data_attributes += " __attribute__ ((aligned (4)))"
-        elif MP_NATIVE_ARCH_ARMV6M <= config.native_arch <= MP_NATIVE_ARCH_ARMV7EMDP:
-            # ARMVxxM -- two byte align.
+        elif (
+            MP_NATIVE_ARCH_ARMV6M <= config.native_arch <= MP_NATIVE_ARCH_ARMV7EMDP
+        ) or config.native_arch == MP_NATIVE_ARCH_RV32IMC:
+            # ARMVxxM or RV32IMC -- two byte align.
             self.fun_data_attributes += " __attribute__ ((aligned (2)))"
 
     def disassemble(self):
@@ -1473,21 +1493,20 @@ def freeze_mpy(firmware_qstr_idents, compiled_modules):
     raw_code_count = 0
     raw_code_content = 0
 
-    print()
-    print("const qstr_hash_t mp_qstr_frozen_const_hashes[] = {")
-    qstr_size = {"metadata": 0, "data": 0}
-    for _, _, _, qbytes in new:
-        qhash = qstrutil.compute_hash(qbytes, config.MICROPY_QSTR_BYTES_IN_HASH)
-        print("    %d," % qhash)
-    print("};")
+    if config.MICROPY_QSTR_BYTES_IN_HASH:
+        print()
+        print("const qstr_hash_t mp_qstr_frozen_const_hashes[] = {")
+        for _, _, _, qbytes in new:
+            qhash = qstrutil.compute_hash(qbytes, config.MICROPY_QSTR_BYTES_IN_HASH)
+            print("    %d," % qhash)
+            qstr_content += config.MICROPY_QSTR_BYTES_IN_HASH
+        print("};")
     print()
     print("const qstr_len_t mp_qstr_frozen_const_lengths[] = {")
     for _, _, _, qbytes in new:
         print("    %d," % len(qbytes))
-        qstr_size["metadata"] += (
-            config.MICROPY_QSTR_BYTES_IN_LEN + config.MICROPY_QSTR_BYTES_IN_HASH
-        )
-        qstr_size["data"] += len(qbytes)
+        qstr_content += config.MICROPY_QSTR_BYTES_IN_LEN
+        qstr_content += len(qbytes) + 1  # include NUL
     print("};")
     print()
     print("extern const qstr_pool_t mp_qstr_const_pool;")
@@ -1497,14 +1516,12 @@ def freeze_mpy(firmware_qstr_idents, compiled_modules):
     print("    true, // is_sorted")
     print("    %u, // allocated entries" % qstr_pool_alloc)
     print("    %u, // used entries" % len(new))
-    print("    (qstr_hash_t *)mp_qstr_frozen_const_hashes,")
+    if config.MICROPY_QSTR_BYTES_IN_HASH:
+        print("    (qstr_hash_t *)mp_qstr_frozen_const_hashes,")
     print("    (qstr_len_t *)mp_qstr_frozen_const_lengths,")
     print("    {")
     for _, _, qstr, qbytes in new:
         print('        "%s",' % qstrutil.escape_bytes(qstr, qbytes))
-        qstr_content += (
-            config.MICROPY_QSTR_BYTES_IN_LEN + config.MICROPY_QSTR_BYTES_IN_HASH + len(qbytes) + 1
-        )
     print("    },")
     print("};")
 
@@ -1717,10 +1734,13 @@ def merge_mpy(compiled_modules, output_file):
         bytecode.append(0b00000010)  # prelude size (n_info=1, n_cell=0)
         bytecode.extend(b"\x00")  # simple_name: qstr index 0 (will use source filename)
         for idx in range(len(compiled_modules)):
-            bytecode.append(0x32)  # MP_BC_MAKE_FUNCTION
-            bytecode.append(idx)  # index raw code
-            bytecode.extend(b"\x34\x00\x59")  # MP_BC_CALL_FUNCTION, 0 args, MP_BC_POP_TOP
-        bytecode.extend(b"\x51\x63")  # MP_BC_LOAD_NONE, MP_BC_RETURN_VALUE
+            bytecode.append(Opcode.MP_BC_MAKE_FUNCTION)
+            bytecode.extend(mp_encode_uint(idx))  # index of raw code
+            bytecode.append(Opcode.MP_BC_CALL_FUNCTION)
+            bytecode.append(0)  # 0 arguments
+            bytecode.append(Opcode.MP_BC_POP_TOP)
+        bytecode.append(Opcode.MP_BC_LOAD_CONST_NONE)
+        bytecode.append(Opcode.MP_BC_RETURN_VALUE)
 
         merged_mpy.extend(mp_encode_uint(len(bytecode) << 3 | 1 << 2))  # length, has_children
         merged_mpy.extend(bytecode)
@@ -1798,7 +1818,7 @@ def main():
     else:
         config.MICROPY_QSTR_BYTES_IN_LEN = 1
         config.MICROPY_QSTR_BYTES_IN_HASH = 1
-        firmware_qstr_idents = set(qstrutil.static_qstr_list)
+        firmware_qstr_idents = set(qstrutil.static_qstr_list_ident)
 
     # Create initial list of global qstrs.
     global_qstrs = GlobalQStrList()
